<?php
/**
 * States
 *
 * Returns an array of country states. 
 * States should be defined in English and translated native through localisation files.
 * Country codes and states (or province) names should follow the Unicode CLDR recommendation (http://cldr.unicode.org/translation/country-names).
 * Countries defined with empty arrays have no states.
 *
 * @package Studiocart/includes
 * @version 2.1.7
 */

defined( 'ABSPATH' ) || exit;

return array(
	'AF' => array(),
	'AO' => array( // Angola states.
		'BGO' => esc_html__( 'Bengo', "ncs-cart" ),
		'BLU' => esc_html__( 'Benguela', "ncs-cart" ),
		'BIE' => esc_html__( 'Bié', "ncs-cart" ),
		'CAB' => esc_html__( 'Cabinda', "ncs-cart" ),
		'CNN' => esc_html__( 'Cunene', "ncs-cart" ),
		'HUA' => esc_html__( 'Huambo', "ncs-cart" ),
		'HUI' => esc_html__( 'Huíla', "ncs-cart" ),
		'CCU' => esc_html__( 'Kuando Kubango', "ncs-cart" ),
		'CNO' => esc_html__( 'Kwanza-Norte', "ncs-cart" ),
		'CUS' => esc_html__( 'Kwanza-Sul', "ncs-cart" ),
		'LUA' => esc_html__( 'Luanda', "ncs-cart" ),
		'LNO' => esc_html__( 'Lunda-Norte', "ncs-cart" ),
		'LSU' => esc_html__( 'Lunda-Sul', "ncs-cart" ),
		'MAL' => esc_html__( 'Malanje', "ncs-cart" ),
		'MOX' => esc_html__( 'Moxico', "ncs-cart" ),
		'NAM' => esc_html__( 'Namibe', "ncs-cart" ),
		'UIG' => esc_html__( 'Uíge', "ncs-cart" ),
		'ZAI' => esc_html__( 'Zaire', "ncs-cart" ),
	),
	'AR' => array( // Argentinian provinces.
		'C' => esc_html__( 'Ciudad Autónoma de Buenos Aires', "ncs-cart" ),
		'B' => esc_html__( 'Buenos Aires', "ncs-cart" ),
		'K' => esc_html__( 'Catamarca', "ncs-cart" ),
		'H' => esc_html__( 'Chaco', "ncs-cart" ),
		'U' => esc_html__( 'Chubut', "ncs-cart" ),
		'X' => esc_html__( 'Córdoba', "ncs-cart" ),
		'W' => esc_html__( 'Corrientes', "ncs-cart" ),
		'E' => esc_html__( 'Entre Ríos', "ncs-cart" ),
		'P' => esc_html__( 'Formosa', "ncs-cart" ),
		'Y' => esc_html__( 'Jujuy', "ncs-cart" ),
		'L' => esc_html__( 'La Pampa', "ncs-cart" ),
		'F' => esc_html__( 'La Rioja', "ncs-cart" ),
		'M' => esc_html__( 'Mendoza', "ncs-cart" ),
		'N' => esc_html__( 'Misiones', "ncs-cart" ),
		'Q' => esc_html__( 'Neuquén', "ncs-cart" ),
		'R' => esc_html__( 'Río Negro', "ncs-cart" ),
		'A' => esc_html__( 'Salta', "ncs-cart" ),
		'J' => esc_html__( 'San Juan', "ncs-cart" ),
		'D' => esc_html__( 'San Luis', "ncs-cart" ),
		'Z' => esc_html__( 'Santa Cruz', "ncs-cart" ),
		'S' => esc_html__( 'Santa Fe', "ncs-cart" ),
		'G' => esc_html__( 'Santiago del Estero', "ncs-cart" ),
		'V' => esc_html__( 'Tierra del Fuego', "ncs-cart" ),
		'T' => esc_html__( 'Tucumán', "ncs-cart" ),
	),
	'AT' => array(),
	'AU' => array( // Australian states.
		'ACT' => esc_html__( 'Australian Capital Territory', "ncs-cart" ),
		'NSW' => esc_html__( 'New South Wales', "ncs-cart" ),
		'NT'  => esc_html__( 'Northern Territory', "ncs-cart" ),
		'QLD' => esc_html__( 'Queensland', "ncs-cart" ),
		'SA'  => esc_html__( 'South Australia', "ncs-cart" ),
		'TAS' => esc_html__( 'Tasmania', "ncs-cart" ),
		'VIC' => esc_html__( 'Victoria', "ncs-cart" ),
		'WA'  => esc_html__( 'Western Australia', "ncs-cart" ),
	),
	'AX' => array(),
	'BD' => array( // Bangladeshi states (districts).
		'BD-05' => esc_html__( 'Bagerhat', "ncs-cart" ),
		'BD-01' => esc_html__( 'Bandarban', "ncs-cart" ),
		'BD-02' => esc_html__( 'Barguna', "ncs-cart" ),
		'BD-06' => esc_html__( 'Barishal', "ncs-cart" ),
		'BD-07' => esc_html__( 'Bhola', "ncs-cart" ),
		'BD-03' => esc_html__( 'Bogura', "ncs-cart" ),
		'BD-04' => esc_html__( 'Brahmanbaria', "ncs-cart" ),
		'BD-09' => esc_html__( 'Chandpur', "ncs-cart" ),
		'BD-10' => esc_html__( 'Chattogram', "ncs-cart" ),
		'BD-12' => esc_html__( 'Chuadanga', "ncs-cart" ),
		'BD-11' => esc_html__( "Cox's Bazar", "ncs-cart" ),
		'BD-08' => esc_html__( 'Cumilla', "ncs-cart" ),
		'BD-13' => esc_html__( 'Dhaka', "ncs-cart" ),
		'BD-14' => esc_html__( 'Dinajpur', "ncs-cart" ),
		'BD-15' => esc_html__( 'Faridpur ', "ncs-cart" ),
		'BD-16' => esc_html__( 'Feni', "ncs-cart" ),
		'BD-19' => esc_html__( 'Gaibandha', "ncs-cart" ),
		'BD-18' => esc_html__( 'Gazipur', "ncs-cart" ),
		'BD-17' => esc_html__( 'Gopalganj', "ncs-cart" ),
		'BD-20' => esc_html__( 'Habiganj', "ncs-cart" ),
		'BD-21' => esc_html__( 'Jamalpur', "ncs-cart" ),
		'BD-22' => esc_html__( 'Jashore', "ncs-cart" ),
		'BD-25' => esc_html__( 'Jhalokati', "ncs-cart" ),
		'BD-23' => esc_html__( 'Jhenaidah', "ncs-cart" ),
		'BD-24' => esc_html__( 'Joypurhat', "ncs-cart" ),
		'BD-29' => esc_html__( 'Khagrachhari', "ncs-cart" ),
		'BD-27' => esc_html__( 'Khulna', "ncs-cart" ),
		'BD-26' => esc_html__( 'Kishoreganj', "ncs-cart" ),
		'BD-28' => esc_html__( 'Kurigram', "ncs-cart" ),
		'BD-30' => esc_html__( 'Kushtia', "ncs-cart" ),
		'BD-31' => esc_html__( 'Lakshmipur', "ncs-cart" ),
		'BD-32' => esc_html__( 'Lalmonirhat', "ncs-cart" ),
		'BD-36' => esc_html__( 'Madaripur', "ncs-cart" ),
		'BD-37' => esc_html__( 'Magura', "ncs-cart" ),
		'BD-33' => esc_html__( 'Manikganj ', "ncs-cart" ),
		'BD-39' => esc_html__( 'Meherpur', "ncs-cart" ),
		'BD-38' => esc_html__( 'Moulvibazar', "ncs-cart" ),
		'BD-35' => esc_html__( 'Munshiganj', "ncs-cart" ),
		'BD-34' => esc_html__( 'Mymensingh', "ncs-cart" ),
		'BD-48' => esc_html__( 'Naogaon', "ncs-cart" ),
		'BD-43' => esc_html__( 'Narail', "ncs-cart" ),
		'BD-40' => esc_html__( 'Narayanganj', "ncs-cart" ),
		'BD-42' => esc_html__( 'Narsingdi', "ncs-cart" ),
		'BD-44' => esc_html__( 'Natore', "ncs-cart" ),
		'BD-45' => esc_html__( 'Nawabganj', "ncs-cart" ),
		'BD-41' => esc_html__( 'Netrakona', "ncs-cart" ),
		'BD-46' => esc_html__( 'Nilphamari', "ncs-cart" ),
		'BD-47' => esc_html__( 'Noakhali', "ncs-cart" ),
		'BD-49' => esc_html__( 'Pabna', "ncs-cart" ),
		'BD-52' => esc_html__( 'Panchagarh', "ncs-cart" ),
		'BD-51' => esc_html__( 'Patuakhali', "ncs-cart" ),
		'BD-50' => esc_html__( 'Pirojpur', "ncs-cart" ),
		'BD-53' => esc_html__( 'Rajbari', "ncs-cart" ),
		'BD-54' => esc_html__( 'Rajshahi', "ncs-cart" ),
		'BD-56' => esc_html__( 'Rangamati', "ncs-cart" ),
		'BD-55' => esc_html__( 'Rangpur', "ncs-cart" ),
		'BD-58' => esc_html__( 'Satkhira', "ncs-cart" ),
		'BD-62' => esc_html__( 'Shariatpur', "ncs-cart" ),
		'BD-57' => esc_html__( 'Sherpur', "ncs-cart" ),
		'BD-59' => esc_html__( 'Sirajganj', "ncs-cart" ),
		'BD-61' => esc_html__( 'Sunamganj', "ncs-cart" ),
		'BD-60' => esc_html__( 'Sylhet', "ncs-cart" ),
		'BD-63' => esc_html__( 'Tangail', "ncs-cart" ),
		'BD-64' => esc_html__( 'Thakurgaon', "ncs-cart" ),
	),
	'BE' => array(),
	'BG' => array( // Bulgarian states.
		'BG-01' => esc_html__( 'Blagoevgrad', "ncs-cart" ),
		'BG-02' => esc_html__( 'Burgas', "ncs-cart" ),
		'BG-08' => esc_html__( 'Dobrich', "ncs-cart" ),
		'BG-07' => esc_html__( 'Gabrovo', "ncs-cart" ),
		'BG-26' => esc_html__( 'Haskovo', "ncs-cart" ),
		'BG-09' => esc_html__( 'Kardzhali', "ncs-cart" ),
		'BG-10' => esc_html__( 'Kyustendil', "ncs-cart" ),
		'BG-11' => esc_html__( 'Lovech', "ncs-cart" ),
		'BG-12' => esc_html__( 'Montana', "ncs-cart" ),
		'BG-13' => esc_html__( 'Pazardzhik', "ncs-cart" ),
		'BG-14' => esc_html__( 'Pernik', "ncs-cart" ),
		'BG-15' => esc_html__( 'Pleven', "ncs-cart" ),
		'BG-16' => esc_html__( 'Plovdiv', "ncs-cart" ),
		'BG-17' => esc_html__( 'Razgrad', "ncs-cart" ),
		'BG-18' => esc_html__( 'Ruse', "ncs-cart" ),
		'BG-27' => esc_html__( 'Shumen', "ncs-cart" ),
		'BG-19' => esc_html__( 'Silistra', "ncs-cart" ),
		'BG-20' => esc_html__( 'Sliven', "ncs-cart" ),
		'BG-21' => esc_html__( 'Smolyan', "ncs-cart" ),
		'BG-23' => esc_html__( 'Sofia', "ncs-cart" ),
		'BG-22' => esc_html__( 'Sofia-Grad', "ncs-cart" ),
		'BG-24' => esc_html__( 'Stara Zagora', "ncs-cart" ),
		'BG-25' => esc_html__( 'Targovishte', "ncs-cart" ),
		'BG-03' => esc_html__( 'Varna', "ncs-cart" ),
		'BG-04' => esc_html__( 'Veliko Tarnovo', "ncs-cart" ),
		'BG-05' => esc_html__( 'Vidin', "ncs-cart" ),
		'BG-06' => esc_html__( 'Vratsa', "ncs-cart" ),
		'BG-28' => esc_html__( 'Yambol', "ncs-cart" ),
	),
	'BH' => array(),
	'BI' => array(),
	'BO' => array( // Bolivian states.
		'B' => esc_html__( 'Chuquisaca', "ncs-cart" ),
		'H' => esc_html__( 'Beni', "ncs-cart" ),
		'C' => esc_html__( 'Cochabamba', "ncs-cart" ),
		'L' => esc_html__( 'La Paz', "ncs-cart" ),
		'O' => esc_html__( 'Oruro', "ncs-cart" ),
		'N' => esc_html__( 'Pando', "ncs-cart" ),
		'P' => esc_html__( 'Potosí', "ncs-cart" ),
		'S' => esc_html__( 'Santa Cruz', "ncs-cart" ),
		'T' => esc_html__( 'Tarija', "ncs-cart" ),
	),
	'BR' => array( // Brazillian states.
		'AC' => esc_html__( 'Acre', "ncs-cart" ),
		'AL' => esc_html__( 'Alagoas', "ncs-cart" ),
		'AP' => esc_html__( 'Amapá', "ncs-cart" ),
		'AM' => esc_html__( 'Amazonas', "ncs-cart" ),
		'BA' => esc_html__( 'Bahia', "ncs-cart" ),
		'CE' => esc_html__( 'Ceará', "ncs-cart" ),
		'DF' => esc_html__( 'Distrito Federal', "ncs-cart" ),
		'ES' => esc_html__( 'Espírito Santo', "ncs-cart" ),
		'GO' => esc_html__( 'Goiás', "ncs-cart" ),
		'MA' => esc_html__( 'Maranhão', "ncs-cart" ),
		'MT' => esc_html__( 'Mato Grosso', "ncs-cart" ),
		'MS' => esc_html__( 'Mato Grosso do Sul', "ncs-cart" ),
		'MG' => esc_html__( 'Minas Gerais', "ncs-cart" ),
		'PA' => esc_html__( 'Pará', "ncs-cart" ),
		'PB' => esc_html__( 'Paraíba', "ncs-cart" ),
		'PR' => esc_html__( 'Paraná', "ncs-cart" ),
		'PE' => esc_html__( 'Pernambuco', "ncs-cart" ),
		'PI' => esc_html__( 'Piauí', "ncs-cart" ),
		'RJ' => esc_html__( 'Rio de Janeiro', "ncs-cart" ),
		'RN' => esc_html__( 'Rio Grande do Norte', "ncs-cart" ),
		'RS' => esc_html__( 'Rio Grande do Sul', "ncs-cart" ),
		'RO' => esc_html__( 'Rondônia', "ncs-cart" ),
		'RR' => esc_html__( 'Roraima', "ncs-cart" ),
		'SC' => esc_html__( 'Santa Catarina', "ncs-cart" ),
		'SP' => esc_html__( 'São Paulo', "ncs-cart" ),
		'SE' => esc_html__( 'Sergipe', "ncs-cart" ),
		'TO' => esc_html__( 'Tocantins', "ncs-cart" ),
	),
	'CA' => array( // Canadian states.
		'AB' => esc_html__( 'Alberta', "ncs-cart" ),
		'BC' => esc_html__( 'British Columbia', "ncs-cart" ),
		'MB' => esc_html__( 'Manitoba', "ncs-cart" ),
		'NB' => esc_html__( 'New Brunswick', "ncs-cart" ),
		'NL' => esc_html__( 'Newfoundland and Labrador', "ncs-cart" ),
		'NT' => esc_html__( 'Northwest Territories', "ncs-cart" ),
		'NS' => esc_html__( 'Nova Scotia', "ncs-cart" ),
		'NU' => esc_html__( 'Nunavut', "ncs-cart" ),
		'ON' => esc_html__( 'Ontario', "ncs-cart" ),
		'PE' => esc_html__( 'Prince Edward Island', "ncs-cart" ),
		'QC' => esc_html__( 'Quebec', "ncs-cart" ),
		'SK' => esc_html__( 'Saskatchewan', "ncs-cart" ),
		'YT' => esc_html__( 'Yukon Territory', "ncs-cart" ),
	),
	'CH' => array( // Cantons of Switzerland.
		'AG' => esc_html__( 'Aargau', "ncs-cart" ),
		'AR' => esc_html__( 'Appenzell Ausserrhoden', "ncs-cart" ),
		'AI' => esc_html__( 'Appenzell Innerrhoden', "ncs-cart" ),
		'BL' => esc_html__( 'Basel-Landschaft', "ncs-cart" ),
		'BS' => esc_html__( 'Basel-Stadt', "ncs-cart" ),
		'BE' => esc_html__( 'Bern', "ncs-cart" ),
		'FR' => esc_html__( 'Fribourg', "ncs-cart" ),
		'GE' => esc_html__( 'Geneva', "ncs-cart" ),
		'GL' => esc_html__( 'Glarus', "ncs-cart" ),
		'GR' => esc_html__( 'Graubünden', "ncs-cart" ),
		'JU' => esc_html__( 'Jura', "ncs-cart" ),
		'LU' => esc_html__( 'Luzern', "ncs-cart" ),
		'NE' => esc_html__( 'Neuchâtel', "ncs-cart" ),
		'NW' => esc_html__( 'Nidwalden', "ncs-cart" ),
		'OW' => esc_html__( 'Obwalden', "ncs-cart" ),
		'SH' => esc_html__( 'Schaffhausen', "ncs-cart" ),
		'SZ' => esc_html__( 'Schwyz', "ncs-cart" ),
		'SO' => esc_html__( 'Solothurn', "ncs-cart" ),
		'SG' => esc_html__( 'St. Gallen', "ncs-cart" ),
		'TG' => esc_html__( 'Thurgau', "ncs-cart" ),
		'TI' => esc_html__( 'Ticino', "ncs-cart" ),
		'UR' => esc_html__( 'Uri', "ncs-cart" ),
		'VS' => esc_html__( 'Valais', "ncs-cart" ),
		'VD' => esc_html__( 'Vaud', "ncs-cart" ),
		'ZG' => esc_html__( 'Zug', "ncs-cart" ),
		'ZH' => esc_html__( 'Zürich', "ncs-cart" ),
	),
	'CN' => array( // Chinese states.
		'CN1'  => esc_html__( 'Yunnan / 云南', "ncs-cart" ),
		'CN2'  => esc_html__( 'Beijing / 北京', "ncs-cart" ),
		'CN3'  => esc_html__( 'Tianjin / 天津', "ncs-cart" ),
		'CN4'  => esc_html__( 'Hebei / 河北', "ncs-cart" ),
		'CN5'  => esc_html__( 'Shanxi / 山西', "ncs-cart" ),
		'CN6'  => esc_html__( 'Inner Mongolia / 內蒙古', "ncs-cart" ),
		'CN7'  => esc_html__( 'Liaoning / 辽宁', "ncs-cart" ),
		'CN8'  => esc_html__( 'Jilin / 吉林', "ncs-cart" ),
		'CN9'  => esc_html__( 'Heilongjiang / 黑龙江', "ncs-cart" ),
		'CN10' => esc_html__( 'Shanghai / 上海', "ncs-cart" ),
		'CN11' => esc_html__( 'Jiangsu / 江苏', "ncs-cart" ),
		'CN12' => esc_html__( 'Zhejiang / 浙江', "ncs-cart" ),
		'CN13' => esc_html__( 'Anhui / 安徽', "ncs-cart" ),
		'CN14' => esc_html__( 'Fujian / 福建', "ncs-cart" ),
		'CN15' => esc_html__( 'Jiangxi / 江西', "ncs-cart" ),
		'CN16' => esc_html__( 'Shandong / 山东', "ncs-cart" ),
		'CN17' => esc_html__( 'Henan / 河南', "ncs-cart" ),
		'CN18' => esc_html__( 'Hubei / 湖北', "ncs-cart" ),
		'CN19' => esc_html__( 'Hunan / 湖南', "ncs-cart" ),
		'CN20' => esc_html__( 'Guangdong / 广东', "ncs-cart" ),
		'CN21' => esc_html__( 'Guangxi Zhuang / 广西壮族', "ncs-cart" ),
		'CN22' => esc_html__( 'Hainan / 海南', "ncs-cart" ),
		'CN23' => esc_html__( 'Chongqing / 重庆', "ncs-cart" ),
		'CN24' => esc_html__( 'Sichuan / 四川', "ncs-cart" ),
		'CN25' => esc_html__( 'Guizhou / 贵州', "ncs-cart" ),
		'CN26' => esc_html__( 'Shaanxi / 陕西', "ncs-cart" ),
		'CN27' => esc_html__( 'Gansu / 甘肃', "ncs-cart" ),
		'CN28' => esc_html__( 'Qinghai / 青海', "ncs-cart" ),
		'CN29' => esc_html__( 'Ningxia Hui / 宁夏', "ncs-cart" ),
		'CN30' => esc_html__( 'Macao / 澳门', "ncs-cart" ),
		'CN31' => esc_html__( 'Tibet / 西藏', "ncs-cart" ),
		'CN32' => esc_html__( 'Xinjiang / 新疆', "ncs-cart" ),
	),
	'CZ' => array(),
	'DE' => array(),
	'DK' => array(),
	'DZ' => array(
		'DZ-01' => esc_html__( 'Adrar', "ncs-cart" ),
		'DZ-02' => esc_html__( 'Chlef', "ncs-cart" ),
		'DZ-03' => esc_html__( 'Laghouat', "ncs-cart" ),
		'DZ-04' => esc_html__( 'Oum El Bouaghi', "ncs-cart" ),
		'DZ-05' => esc_html__( 'Batna', "ncs-cart" ),
		'DZ-06' => esc_html__( 'Béjaïa', "ncs-cart" ),
		'DZ-07' => esc_html__( 'Biskra', "ncs-cart" ),
		'DZ-08' => esc_html__( 'Béchar', "ncs-cart" ),
		'DZ-09' => esc_html__( 'Blida', "ncs-cart" ),
		'DZ-10' => esc_html__( 'Bouira', "ncs-cart" ),
		'DZ-11' => esc_html__( 'Tamanghasset', "ncs-cart" ),
		'DZ-12' => esc_html__( 'Tébessa', "ncs-cart" ),
		'DZ-13' => esc_html__( 'Tlemcen', "ncs-cart" ),
		'DZ-14' => esc_html__( 'Tiaret', "ncs-cart" ),
		'DZ-15' => esc_html__( 'Tizi Ouzou', "ncs-cart" ),
		'DZ-16' => esc_html__( 'Algiers', "ncs-cart" ),
		'DZ-17' => esc_html__( 'Djelfa', "ncs-cart" ),
		'DZ-18' => esc_html__( 'Jijel', "ncs-cart" ),
		'DZ-19' => esc_html__( 'Sétif', "ncs-cart" ),
		'DZ-20' => esc_html__( 'Saïda', "ncs-cart" ),
		'DZ-21' => esc_html__( 'Skikda', "ncs-cart" ),
		'DZ-22' => esc_html__( 'Sidi Bel Abbès', "ncs-cart" ),
		'DZ-23' => esc_html__( 'Annaba', "ncs-cart" ),
		'DZ-24' => esc_html__( 'Guelma', "ncs-cart" ),
		'DZ-25' => esc_html__( 'Constantine', "ncs-cart" ),
		'DZ-26' => esc_html__( 'Médéa', "ncs-cart" ),
		'DZ-27' => esc_html__( 'Mostaganem', "ncs-cart" ),
		'DZ-28' => esc_html__( 'M’Sila', "ncs-cart" ),
		'DZ-29' => esc_html__( 'Mascara', "ncs-cart" ),
		'DZ-30' => esc_html__( 'Ouargla', "ncs-cart" ),
		'DZ-31' => esc_html__( 'Oran', "ncs-cart" ),
		'DZ-32' => esc_html__( 'El Bayadh', "ncs-cart" ),
		'DZ-33' => esc_html__( 'Illizi', "ncs-cart" ),
		'DZ-34' => esc_html__( 'Bordj Bou Arréridj', "ncs-cart" ),
		'DZ-35' => esc_html__( 'Boumerdès', "ncs-cart" ),
		'DZ-36' => esc_html__( 'El Tarf', "ncs-cart" ),
		'DZ-37' => esc_html__( 'Tindouf', "ncs-cart" ),
		'DZ-38' => esc_html__( 'Tissemsilt', "ncs-cart" ),
		'DZ-39' => esc_html__( 'El Oued', "ncs-cart" ),
		'DZ-40' => esc_html__( 'Khenchela', "ncs-cart" ),
		'DZ-41' => esc_html__( 'Souk Ahras', "ncs-cart" ),
		'DZ-42' => esc_html__( 'Tipasa', "ncs-cart" ),
		'DZ-43' => esc_html__( 'Mila', "ncs-cart" ),
		'DZ-44' => esc_html__( 'Aïn Defla', "ncs-cart" ),
		'DZ-45' => esc_html__( 'Naama', "ncs-cart" ),
		'DZ-46' => esc_html__( 'Aïn Témouchent', "ncs-cart" ),
		'DZ-47' => esc_html__( 'Ghardaïa', "ncs-cart" ),
		'DZ-48' => esc_html__( 'Relizane', "ncs-cart" ),
	),
	'EE' => array(),
	'ES' => array( // Spanish states.
		'C'  => esc_html__( 'A Coruña', "ncs-cart" ),
		'VI' => esc_html__( 'Araba/Álava', "ncs-cart" ),
		'AB' => esc_html__( 'Albacete', "ncs-cart" ),
		'A'  => esc_html__( 'Alicante', "ncs-cart" ),
		'AL' => esc_html__( 'Almería', "ncs-cart" ),
		'O'  => esc_html__( 'Asturias', "ncs-cart" ),
		'AV' => esc_html__( 'Ávila', "ncs-cart" ),
		'BA' => esc_html__( 'Badajoz', "ncs-cart" ),
		'PM' => esc_html__( 'Baleares', "ncs-cart" ),
		'B'  => esc_html__( 'Barcelona', "ncs-cart" ),
		'BU' => esc_html__( 'Burgos', "ncs-cart" ),
		'CC' => esc_html__( 'Cáceres', "ncs-cart" ),
		'CA' => esc_html__( 'Cádiz', "ncs-cart" ),
		'S'  => esc_html__( 'Cantabria', "ncs-cart" ),
		'CS' => esc_html__( 'Castellón', "ncs-cart" ),
		'CE' => esc_html__( 'Ceuta', "ncs-cart" ),
		'CR' => esc_html__( 'Ciudad Real', "ncs-cart" ),
		'CO' => esc_html__( 'Córdoba', "ncs-cart" ),
		'CU' => esc_html__( 'Cuenca', "ncs-cart" ),
		'GI' => esc_html__( 'Girona', "ncs-cart" ),
		'GR' => esc_html__( 'Granada', "ncs-cart" ),
		'GU' => esc_html__( 'Guadalajara', "ncs-cart" ),
		'SS' => esc_html__( 'Gipuzkoa', "ncs-cart" ),
		'H'  => esc_html__( 'Huelva', "ncs-cart" ),
		'HU' => esc_html__( 'Huesca', "ncs-cart" ),
		'J'  => esc_html__( 'Jaén', "ncs-cart" ),
		'LO' => esc_html__( 'La Rioja', "ncs-cart" ),
		'GC' => esc_html__( 'Las Palmas', "ncs-cart" ),
		'LE' => esc_html__( 'León', "ncs-cart" ),
		'L'  => esc_html__( 'Lleida', "ncs-cart" ),
		'LU' => esc_html__( 'Lugo', "ncs-cart" ),
		'M'  => esc_html__( 'Madrid', "ncs-cart" ),
		'MA' => esc_html__( 'Málaga', "ncs-cart" ),
		'ML' => esc_html__( 'Melilla', "ncs-cart" ),
		'MU' => esc_html__( 'Murcia', "ncs-cart" ),
		'NA' => esc_html__( 'Navarra', "ncs-cart" ),
		'OR' => esc_html__( 'Ourense', "ncs-cart" ),
		'P'  => esc_html__( 'Palencia', "ncs-cart" ),
		'PO' => esc_html__( 'Pontevedra', "ncs-cart" ),
		'SA' => esc_html__( 'Salamanca', "ncs-cart" ),
		'TF' => esc_html__( 'Santa Cruz de Tenerife', "ncs-cart" ),
		'SG' => esc_html__( 'Segovia', "ncs-cart" ),
		'SE' => esc_html__( 'Sevilla', "ncs-cart" ),
		'SO' => esc_html__( 'Soria', "ncs-cart" ),
		'T'  => esc_html__( 'Tarragona', "ncs-cart" ),
		'TE' => esc_html__( 'Teruel', "ncs-cart" ),
		'TO' => esc_html__( 'Toledo', "ncs-cart" ),
		'V'  => esc_html__( 'Valencia', "ncs-cart" ),
		'VA' => esc_html__( 'Valladolid', "ncs-cart" ),
		'BI' => esc_html__( 'Bizkaia', "ncs-cart" ),
		'ZA' => esc_html__( 'Zamora', "ncs-cart" ),
		'Z'  => esc_html__( 'Zaragoza', "ncs-cart" ),
	),
	'FI' => array(),
	'FR' => array(),
	'GH' => array( // Ghanaian Regions.
		'AF' => esc_html__( 'Ahafo', "ncs-cart" ),
		'AH' => esc_html__( 'Ashanti', "ncs-cart" ),
		'BA' => esc_html__( 'Brong-Ahafo', "ncs-cart" ),
		'BO' => esc_html__( 'Bono', "ncs-cart" ),
		'BE' => esc_html__( 'Bono East', "ncs-cart" ),
		'CP' => esc_html__( 'Central', "ncs-cart" ),
		'EP' => esc_html__( 'Eastern', "ncs-cart" ),
		'AA' => esc_html__( 'Greater Accra', "ncs-cart" ),
		'NE' => esc_html__( 'North East', "ncs-cart" ),
		'NP' => esc_html__( 'Northern', "ncs-cart" ),
		'OT' => esc_html__( 'Oti', "ncs-cart" ),
		'SV' => esc_html__( 'Savannah', "ncs-cart" ),
		'UE' => esc_html__( 'Upper East', "ncs-cart" ),
		'UW' => esc_html__( 'Upper West', "ncs-cart" ),
		'TV' => esc_html__( 'Volta', "ncs-cart" ),
		'WP' => esc_html__( 'Western', "ncs-cart" ),
		'WN' => esc_html__( 'Western North', "ncs-cart" ),
	),
	'GP' => array(),
	'GR' => array( // Greek Regions.
		'I' => esc_html__( 'Attica', "ncs-cart" ),
		'A' => esc_html__( 'East Macedonia and Thrace', "ncs-cart" ),
		'B' => esc_html__( 'Central Macedonia', "ncs-cart" ),
		'C' => esc_html__( 'West Macedonia', "ncs-cart" ),
		'D' => esc_html__( 'Epirus', "ncs-cart" ),
		'E' => esc_html__( 'Thessaly', "ncs-cart" ),
		'F' => esc_html__( 'Ionian Islands', "ncs-cart" ),
		'G' => esc_html__( 'West Greece', "ncs-cart" ),
		'H' => esc_html__( 'Central Greece', "ncs-cart" ),
		'J' => esc_html__( 'Peloponnese', "ncs-cart" ),
		'K' => esc_html__( 'North Aegean', "ncs-cart" ),
		'L' => esc_html__( 'South Aegean', "ncs-cart" ),
		'M' => esc_html__( 'Crete', "ncs-cart" ),
	),
	'GF' => array(),
	'HK' => array( // Hong Kong states.
		'HONG KONG'       => esc_html__( 'Hong Kong Island', "ncs-cart" ),
		'KOWLOON'         => esc_html__( 'Kowloon', "ncs-cart" ),
		'NEW TERRITORIES' => esc_html__( 'New Territories', "ncs-cart" ),
	),
	'HU' => array( // Hungary states.
		'BK' => esc_html__( 'Bács-Kiskun', "ncs-cart" ),
		'BE' => esc_html__( 'Békés', "ncs-cart" ),
		'BA' => esc_html__( 'Baranya', "ncs-cart" ),
		'BZ' => esc_html__( 'Borsod-Abaúj-Zemplén', "ncs-cart" ),
		'BU' => esc_html__( 'Budapest', "ncs-cart" ),
		'CS' => esc_html__( 'Csongrád', "ncs-cart" ),
		'FE' => esc_html__( 'Fejér', "ncs-cart" ),
		'GS' => esc_html__( 'Győr-Moson-Sopron', "ncs-cart" ),
		'HB' => esc_html__( 'Hajdú-Bihar', "ncs-cart" ),
		'HE' => esc_html__( 'Heves', "ncs-cart" ),
		'JN' => esc_html__( 'Jász-Nagykun-Szolnok', "ncs-cart" ),
		'KE' => esc_html__( 'Komárom-Esztergom', "ncs-cart" ),
		'NO' => esc_html__( 'Nógrád', "ncs-cart" ),
		'PE' => esc_html__( 'Pest', "ncs-cart" ),
		'SO' => esc_html__( 'Somogy', "ncs-cart" ),
		'SZ' => esc_html__( 'Szabolcs-Szatmár-Bereg', "ncs-cart" ),
		'TO' => esc_html__( 'Tolna', "ncs-cart" ),
		'VA' => esc_html__( 'Vas', "ncs-cart" ),
		'VE' => esc_html__( 'Veszprém', "ncs-cart" ),
		'ZA' => esc_html__( 'Zala', "ncs-cart" ),
	),
	'ID' => array( // Indonesia Provinces.
		'AC' => esc_html__( 'Daerah Istimewa Aceh', "ncs-cart" ),
		'SU' => esc_html__( 'Sumatera Utara', "ncs-cart" ),
		'SB' => esc_html__( 'Sumatera Barat', "ncs-cart" ),
		'RI' => esc_html__( 'Riau', "ncs-cart" ),
		'KR' => esc_html__( 'Kepulauan Riau', "ncs-cart" ),
		'JA' => esc_html__( 'Jambi', "ncs-cart" ),
		'SS' => esc_html__( 'Sumatera Selatan', "ncs-cart" ),
		'BB' => esc_html__( 'Bangka Belitung', "ncs-cart" ),
		'BE' => esc_html__( 'Bengkulu', "ncs-cart" ),
		'LA' => esc_html__( 'Lampung', "ncs-cart" ),
		'JK' => esc_html__( 'DKI Jakarta', "ncs-cart" ),
		'JB' => esc_html__( 'Jawa Barat', "ncs-cart" ),
		'BT' => esc_html__( 'Banten', "ncs-cart" ),
		'JT' => esc_html__( 'Jawa Tengah', "ncs-cart" ),
		'JI' => esc_html__( 'Jawa Timur', "ncs-cart" ),
		'YO' => esc_html__( 'Daerah Istimewa Yogyakarta', "ncs-cart" ),
		'BA' => esc_html__( 'Bali', "ncs-cart" ),
		'NB' => esc_html__( 'Nusa Tenggara Barat', "ncs-cart" ),
		'NT' => esc_html__( 'Nusa Tenggara Timur', "ncs-cart" ),
		'KB' => esc_html__( 'Kalimantan Barat', "ncs-cart" ),
		'KT' => esc_html__( 'Kalimantan Tengah', "ncs-cart" ),
		'KI' => esc_html__( 'Kalimantan Timur', "ncs-cart" ),
		'KS' => esc_html__( 'Kalimantan Selatan', "ncs-cart" ),
		'KU' => esc_html__( 'Kalimantan Utara', "ncs-cart" ),
		'SA' => esc_html__( 'Sulawesi Utara', "ncs-cart" ),
		'ST' => esc_html__( 'Sulawesi Tengah', "ncs-cart" ),
		'SG' => esc_html__( 'Sulawesi Tenggara', "ncs-cart" ),
		'SR' => esc_html__( 'Sulawesi Barat', "ncs-cart" ),
		'SN' => esc_html__( 'Sulawesi Selatan', "ncs-cart" ),
		'GO' => esc_html__( 'Gorontalo', "ncs-cart" ),
		'MA' => esc_html__( 'Maluku', "ncs-cart" ),
		'MU' => esc_html__( 'Maluku Utara', "ncs-cart" ),
		'PA' => esc_html__( 'Papua', "ncs-cart" ),
		'PB' => esc_html__( 'Papua Barat', "ncs-cart" ),
	),
	'IE' => array( // Republic of Ireland.
		'CW' => esc_html__( 'Carlow', "ncs-cart" ),
		'CN' => esc_html__( 'Cavan', "ncs-cart" ),
		'CE' => esc_html__( 'Clare', "ncs-cart" ),
		'CO' => esc_html__( 'Cork', "ncs-cart" ),
		'DL' => esc_html__( 'Donegal', "ncs-cart" ),
		'D'  => esc_html__( 'Dublin', "ncs-cart" ),
		'G'  => esc_html__( 'Galway', "ncs-cart" ),
		'KY' => esc_html__( 'Kerry', "ncs-cart" ),
		'KE' => esc_html__( 'Kildare', "ncs-cart" ),
		'KK' => esc_html__( 'Kilkenny', "ncs-cart" ),
		'LS' => esc_html__( 'Laois', "ncs-cart" ),
		'LM' => esc_html__( 'Leitrim', "ncs-cart" ),
		'LK' => esc_html__( 'Limerick', "ncs-cart" ),
		'LD' => esc_html__( 'Longford', "ncs-cart" ),
		'LH' => esc_html__( 'Louth', "ncs-cart" ),
		'MO' => esc_html__( 'Mayo', "ncs-cart" ),
		'MH' => esc_html__( 'Meath', "ncs-cart" ),
		'MN' => esc_html__( 'Monaghan', "ncs-cart" ),
		'OY' => esc_html__( 'Offaly', "ncs-cart" ),
		'RN' => esc_html__( 'Roscommon', "ncs-cart" ),
		'SO' => esc_html__( 'Sligo', "ncs-cart" ),
		'TA' => esc_html__( 'Tipperary', "ncs-cart" ),
		'WD' => esc_html__( 'Waterford', "ncs-cart" ),
		'WH' => esc_html__( 'Westmeath', "ncs-cart" ),
		'WX' => esc_html__( 'Wexford', "ncs-cart" ),
		'WW' => esc_html__( 'Wicklow', "ncs-cart" ),
	),
	'IN' => array( // Indian states.
		'AP' => esc_html__( 'Andhra Pradesh', "ncs-cart" ),
		'AR' => esc_html__( 'Arunachal Pradesh', "ncs-cart" ),
		'AS' => esc_html__( 'Assam', "ncs-cart" ),
		'BR' => esc_html__( 'Bihar', "ncs-cart" ),
		'CT' => esc_html__( 'Chhattisgarh', "ncs-cart" ),
		'GA' => esc_html__( 'Goa', "ncs-cart" ),
		'GJ' => esc_html__( 'Gujarat', "ncs-cart" ),
		'HR' => esc_html__( 'Haryana', "ncs-cart" ),
		'HP' => esc_html__( 'Himachal Pradesh', "ncs-cart" ),
		'JK' => esc_html__( 'Jammu and Kashmir', "ncs-cart" ),
		'JH' => esc_html__( 'Jharkhand', "ncs-cart" ),
		'KA' => esc_html__( 'Karnataka', "ncs-cart" ),
		'KL' => esc_html__( 'Kerala', "ncs-cart" ),
		'MP' => esc_html__( 'Madhya Pradesh', "ncs-cart" ),
		'MH' => esc_html__( 'Maharashtra', "ncs-cart" ),
		'MN' => esc_html__( 'Manipur', "ncs-cart" ),
		'ML' => esc_html__( 'Meghalaya', "ncs-cart" ),
		'MZ' => esc_html__( 'Mizoram', "ncs-cart" ),
		'NL' => esc_html__( 'Nagaland', "ncs-cart" ),
		'OR' => esc_html__( 'Orissa', "ncs-cart" ),
		'PB' => esc_html__( 'Punjab', "ncs-cart" ),
		'RJ' => esc_html__( 'Rajasthan', "ncs-cart" ),
		'SK' => esc_html__( 'Sikkim', "ncs-cart" ),
		'TN' => esc_html__( 'Tamil Nadu', "ncs-cart" ),
		'TS' => esc_html__( 'Telangana', "ncs-cart" ),
		'TR' => esc_html__( 'Tripura', "ncs-cart" ),
		'UK' => esc_html__( 'Uttarakhand', "ncs-cart" ),
		'UP' => esc_html__( 'Uttar Pradesh', "ncs-cart" ),
		'WB' => esc_html__( 'West Bengal', "ncs-cart" ),
		'AN' => esc_html__( 'Andaman and Nicobar Islands', "ncs-cart" ),
		'CH' => esc_html__( 'Chandigarh', "ncs-cart" ),
		'DN' => esc_html__( 'Dadra and Nagar Haveli', "ncs-cart" ),
		'DD' => esc_html__( 'Daman and Diu', "ncs-cart" ),
		'DL' => esc_html__( 'Delhi', "ncs-cart" ),
		'LD' => esc_html__( 'Lakshadeep', "ncs-cart" ),
		'PY' => esc_html__( 'Pondicherry (Puducherry)', "ncs-cart" ),
	),
	'IR' => array( // Iran States.
		'KHZ' => esc_html__( 'Khuzestan  (خوزستان)', "ncs-cart" ),
		'THR' => esc_html__( 'Tehran  (تهران)', "ncs-cart" ),
		'ILM' => esc_html__( 'Ilaam (ایلام)', "ncs-cart" ),
		'BHR' => esc_html__( 'Bushehr (بوشهر)', "ncs-cart" ),
		'ADL' => esc_html__( 'Ardabil (اردبیل)', "ncs-cart" ),
		'ESF' => esc_html__( 'Isfahan (اصفهان)', "ncs-cart" ),
		'YZD' => esc_html__( 'Yazd (یزد)', "ncs-cart" ),
		'KRH' => esc_html__( 'Kermanshah (کرمانشاه)', "ncs-cart" ),
		'KRN' => esc_html__( 'Kerman (کرمان)', "ncs-cart" ),
		'HDN' => esc_html__( 'Hamadan (همدان)', "ncs-cart" ),
		'GZN' => esc_html__( 'Ghazvin (قزوین)', "ncs-cart" ),
		'ZJN' => esc_html__( 'Zanjan (زنجان)', "ncs-cart" ),
		'LRS' => esc_html__( 'Luristan (لرستان)', "ncs-cart" ),
		'ABZ' => esc_html__( 'Alborz (البرز)', "ncs-cart" ),
		'EAZ' => esc_html__( 'East Azarbaijan (آذربایجان شرقی)', "ncs-cart" ),
		'WAZ' => esc_html__( 'West Azarbaijan (آذربایجان غربی)', "ncs-cart" ),
		'CHB' => esc_html__( 'Chaharmahal and Bakhtiari (چهارمحال و بختیاری)', "ncs-cart" ),
		'SKH' => esc_html__( 'South Khorasan (خراسان جنوبی)', "ncs-cart" ),
		'RKH' => esc_html__( 'Razavi Khorasan (خراسان رضوی)', "ncs-cart" ),
		'NKH' => esc_html__( 'North Khorasan (خراسان شمالی)', "ncs-cart" ),
		'SMN' => esc_html__( 'Semnan (سمنان)', "ncs-cart" ),
		'FRS' => esc_html__( 'Fars (فارس)', "ncs-cart" ),
		'QHM' => esc_html__( 'Qom (قم)', "ncs-cart" ),
		'KRD' => esc_html__( 'Kurdistan / کردستان)', "ncs-cart" ),
		'KBD' => esc_html__( 'Kohgiluyeh and BoyerAhmad (کهگیلوییه و بویراحمد)', "ncs-cart" ),
		'GLS' => esc_html__( 'Golestan (گلستان)', "ncs-cart" ),
		'GIL' => esc_html__( 'Gilan (گیلان)', "ncs-cart" ),
		'MZN' => esc_html__( 'Mazandaran (مازندران)', "ncs-cart" ),
		'MKZ' => esc_html__( 'Markazi (مرکزی)', "ncs-cart" ),
		'HRZ' => esc_html__( 'Hormozgan (هرمزگان)', "ncs-cart" ),
		'SBN' => esc_html__( 'Sistan and Baluchestan (سیستان و بلوچستان)', "ncs-cart" ),
	),
	'IS' => array(),
	'IT' => array( // Italy Provinces.
		'AG' => esc_html__( 'Agrigento', "ncs-cart" ),
		'AL' => esc_html__( 'Alessandria', "ncs-cart" ),
		'AN' => esc_html__( 'Ancona', "ncs-cart" ),
		'AO' => esc_html__( 'Aosta', "ncs-cart" ),
		'AR' => esc_html__( 'Arezzo', "ncs-cart" ),
		'AP' => esc_html__( 'Ascoli Piceno', "ncs-cart" ),
		'AT' => esc_html__( 'Asti', "ncs-cart" ),
		'AV' => esc_html__( 'Avellino', "ncs-cart" ),
		'BA' => esc_html__( 'Bari', "ncs-cart" ),
		'BT' => esc_html__( 'Barletta-Andria-Trani', "ncs-cart" ),
		'BL' => esc_html__( 'Belluno', "ncs-cart" ),
		'BN' => esc_html__( 'Benevento', "ncs-cart" ),
		'BG' => esc_html__( 'Bergamo', "ncs-cart" ),
		'BI' => esc_html__( 'Biella', "ncs-cart" ),
		'BO' => esc_html__( 'Bologna', "ncs-cart" ),
		'BZ' => esc_html__( 'Bolzano', "ncs-cart" ),
		'BS' => esc_html__( 'Brescia', "ncs-cart" ),
		'BR' => esc_html__( 'Brindisi', "ncs-cart" ),
		'CA' => esc_html__( 'Cagliari', "ncs-cart" ),
		'CL' => esc_html__( 'Caltanissetta', "ncs-cart" ),
		'CB' => esc_html__( 'Campobasso', "ncs-cart" ),
		'CE' => esc_html__( 'Caserta', "ncs-cart" ),
		'CT' => esc_html__( 'Catania', "ncs-cart" ),
		'CZ' => esc_html__( 'Catanzaro', "ncs-cart" ),
		'CH' => esc_html__( 'Chieti', "ncs-cart" ),
		'CO' => esc_html__( 'Como', "ncs-cart" ),
		'CS' => esc_html__( 'Cosenza', "ncs-cart" ),
		'CR' => esc_html__( 'Cremona', "ncs-cart" ),
		'KR' => esc_html__( 'Crotone', "ncs-cart" ),
		'CN' => esc_html__( 'Cuneo', "ncs-cart" ),
		'EN' => esc_html__( 'Enna', "ncs-cart" ),
		'FM' => esc_html__( 'Fermo', "ncs-cart" ),
		'FE' => esc_html__( 'Ferrara', "ncs-cart" ),
		'FI' => esc_html__( 'Firenze', "ncs-cart" ),
		'FG' => esc_html__( 'Foggia', "ncs-cart" ),
		'FC' => esc_html__( 'Forlì-Cesena', "ncs-cart" ),
		'FR' => esc_html__( 'Frosinone', "ncs-cart" ),
		'GE' => esc_html__( 'Genova', "ncs-cart" ),
		'GO' => esc_html__( 'Gorizia', "ncs-cart" ),
		'GR' => esc_html__( 'Grosseto', "ncs-cart" ),
		'IM' => esc_html__( 'Imperia', "ncs-cart" ),
		'IS' => esc_html__( 'Isernia', "ncs-cart" ),
		'SP' => esc_html__( 'La Spezia', "ncs-cart" ),
		'AQ' => esc_html__( "L'Aquila", "ncs-cart" ),
		'LT' => esc_html__( 'Latina', "ncs-cart" ),
		'LE' => esc_html__( 'Lecce', "ncs-cart" ),
		'LC' => esc_html__( 'Lecco', "ncs-cart" ),
		'LI' => esc_html__( 'Livorno', "ncs-cart" ),
		'LO' => esc_html__( 'Lodi', "ncs-cart" ),
		'LU' => esc_html__( 'Lucca', "ncs-cart" ),
		'MC' => esc_html__( 'Macerata', "ncs-cart" ),
		'MN' => esc_html__( 'Mantova', "ncs-cart" ),
		'MS' => esc_html__( 'Massa-Carrara', "ncs-cart" ),
		'MT' => esc_html__( 'Matera', "ncs-cart" ),
		'ME' => esc_html__( 'Messina', "ncs-cart" ),
		'MI' => esc_html__( 'Milano', "ncs-cart" ),
		'MO' => esc_html__( 'Modena', "ncs-cart" ),
		'MB' => esc_html__( 'Monza e della Brianza', "ncs-cart" ),
		'NA' => esc_html__( 'Napoli', "ncs-cart" ),
		'NO' => esc_html__( 'Novara', "ncs-cart" ),
		'NU' => esc_html__( 'Nuoro', "ncs-cart" ),
		'OR' => esc_html__( 'Oristano', "ncs-cart" ),
		'PD' => esc_html__( 'Padova', "ncs-cart" ),
		'PA' => esc_html__( 'Palermo', "ncs-cart" ),
		'PR' => esc_html__( 'Parma', "ncs-cart" ),
		'PV' => esc_html__( 'Pavia', "ncs-cart" ),
		'PG' => esc_html__( 'Perugia', "ncs-cart" ),
		'PU' => esc_html__( 'Pesaro e Urbino', "ncs-cart" ),
		'PE' => esc_html__( 'Pescara', "ncs-cart" ),
		'PC' => esc_html__( 'Piacenza', "ncs-cart" ),
		'PI' => esc_html__( 'Pisa', "ncs-cart" ),
		'PT' => esc_html__( 'Pistoia', "ncs-cart" ),
		'PN' => esc_html__( 'Pordenone', "ncs-cart" ),
		'PZ' => esc_html__( 'Potenza', "ncs-cart" ),
		'PO' => esc_html__( 'Prato', "ncs-cart" ),
		'RG' => esc_html__( 'Ragusa', "ncs-cart" ),
		'RA' => esc_html__( 'Ravenna', "ncs-cart" ),
		'RC' => esc_html__( 'Reggio Calabria', "ncs-cart" ),
		'RE' => esc_html__( 'Reggio Emilia', "ncs-cart" ),
		'RI' => esc_html__( 'Rieti', "ncs-cart" ),
		'RN' => esc_html__( 'Rimini', "ncs-cart" ),
		'RM' => esc_html__( 'Roma', "ncs-cart" ),
		'RO' => esc_html__( 'Rovigo', "ncs-cart" ),
		'SA' => esc_html__( 'Salerno', "ncs-cart" ),
		'SS' => esc_html__( 'Sassari', "ncs-cart" ),
		'SV' => esc_html__( 'Savona', "ncs-cart" ),
		'SI' => esc_html__( 'Siena', "ncs-cart" ),
		'SR' => esc_html__( 'Siracusa', "ncs-cart" ),
		'SO' => esc_html__( 'Sondrio', "ncs-cart" ),
		'SU' => esc_html__( 'Sud Sardegna', "ncs-cart" ),
		'TA' => esc_html__( 'Taranto', "ncs-cart" ),
		'TE' => esc_html__( 'Teramo', "ncs-cart" ),
		'TR' => esc_html__( 'Terni', "ncs-cart" ),
		'TO' => esc_html__( 'Torino', "ncs-cart" ),
		'TP' => esc_html__( 'Trapani', "ncs-cart" ),
		'TN' => esc_html__( 'Trento', "ncs-cart" ),
		'TV' => esc_html__( 'Treviso', "ncs-cart" ),
		'TS' => esc_html__( 'Trieste', "ncs-cart" ),
		'UD' => esc_html__( 'Udine', "ncs-cart" ),
		'VA' => esc_html__( 'Varese', "ncs-cart" ),
		'VE' => esc_html__( 'Venezia', "ncs-cart" ),
		'VB' => esc_html__( 'Verbano-Cusio-Ossola', "ncs-cart" ),
		'VC' => esc_html__( 'Vercelli', "ncs-cart" ),
		'VR' => esc_html__( 'Verona', "ncs-cart" ),
		'VV' => esc_html__( 'Vibo Valentia', "ncs-cart" ),
		'VI' => esc_html__( 'Vicenza', "ncs-cart" ),
		'VT' => esc_html__( 'Viterbo', "ncs-cart" ),
	),
	'IL' => array(),
	'IM' => array(),

	/**
	 * Japan States.
	 *
	 * English notation of prefectures conform to the notation of Japan Post.
	 * The suffix corresponds with the Japanese translation file.
	 */
	'JP' => array(
		'JP01' => esc_html__( 'Hokkaido', "ncs-cart" ),
		'JP02' => esc_html__( 'Aomori', "ncs-cart" ),
		'JP03' => esc_html__( 'Iwate', "ncs-cart" ),
		'JP04' => esc_html__( 'Miyagi', "ncs-cart" ),
		'JP05' => esc_html__( 'Akita', "ncs-cart" ),
		'JP06' => esc_html__( 'Yamagata', "ncs-cart" ),
		'JP07' => esc_html__( 'Fukushima', "ncs-cart" ),
		'JP08' => esc_html__( 'Ibaraki', "ncs-cart" ),
		'JP09' => esc_html__( 'Tochigi', "ncs-cart" ),
		'JP10' => esc_html__( 'Gunma', "ncs-cart" ),
		'JP11' => esc_html__( 'Saitama', "ncs-cart" ),
		'JP12' => esc_html__( 'Chiba', "ncs-cart" ),
		'JP13' => esc_html__( 'Tokyo', "ncs-cart" ),
		'JP14' => esc_html__( 'Kanagawa', "ncs-cart" ),
		'JP15' => esc_html__( 'Niigata', "ncs-cart" ),
		'JP16' => esc_html__( 'Toyama', "ncs-cart" ),
		'JP17' => esc_html__( 'Ishikawa', "ncs-cart" ),
		'JP18' => esc_html__( 'Fukui', "ncs-cart" ),
		'JP19' => esc_html__( 'Yamanashi', "ncs-cart" ),
		'JP20' => esc_html__( 'Nagano', "ncs-cart" ),
		'JP21' => esc_html__( 'Gifu', "ncs-cart" ),
		'JP22' => esc_html__( 'Shizuoka', "ncs-cart" ),
		'JP23' => esc_html__( 'Aichi', "ncs-cart" ),
		'JP24' => esc_html__( 'Mie', "ncs-cart" ),
		'JP25' => esc_html__( 'Shiga', "ncs-cart" ),
		'JP26' => esc_html__( 'Kyoto', "ncs-cart" ),
		'JP27' => esc_html__( 'Osaka', "ncs-cart" ),
		'JP28' => esc_html__( 'Hyogo', "ncs-cart" ),
		'JP29' => esc_html__( 'Nara', "ncs-cart" ),
		'JP30' => esc_html__( 'Wakayama', "ncs-cart" ),
		'JP31' => esc_html__( 'Tottori', "ncs-cart" ),
		'JP32' => esc_html__( 'Shimane', "ncs-cart" ),
		'JP33' => esc_html__( 'Okayama', "ncs-cart" ),
		'JP34' => esc_html__( 'Hiroshima', "ncs-cart" ),
		'JP35' => esc_html__( 'Yamaguchi', "ncs-cart" ),
		'JP36' => esc_html__( 'Tokushima', "ncs-cart" ),
		'JP37' => esc_html__( 'Kagawa', "ncs-cart" ),
		'JP38' => esc_html__( 'Ehime', "ncs-cart" ),
		'JP39' => esc_html__( 'Kochi', "ncs-cart" ),
		'JP40' => esc_html__( 'Fukuoka', "ncs-cart" ),
		'JP41' => esc_html__( 'Saga', "ncs-cart" ),
		'JP42' => esc_html__( 'Nagasaki', "ncs-cart" ),
		'JP43' => esc_html__( 'Kumamoto', "ncs-cart" ),
		'JP44' => esc_html__( 'Oita', "ncs-cart" ),
		'JP45' => esc_html__( 'Miyazaki', "ncs-cart" ),
		'JP46' => esc_html__( 'Kagoshima', "ncs-cart" ),
		'JP47' => esc_html__( 'Okinawa', "ncs-cart" ),
	),
	'KE' => array( // Kenya counties.
		'KE01' => esc_html__( 'Baringo', "ncs-cart" ),
		'KE02' => esc_html__( 'Bomet', "ncs-cart" ),
		'KE03' => esc_html__( 'Bungoma', "ncs-cart" ),
		'KE04' => esc_html__( 'Busia', "ncs-cart" ),
		'KE05' => esc_html__( 'Elgeyo-Marakwet', "ncs-cart" ),
		'KE06' => esc_html__( 'Embu', "ncs-cart" ),
		'KE07' => esc_html__( 'Garissa', "ncs-cart" ),
		'KE08' => esc_html__( 'Homa Bay', "ncs-cart" ),
		'KE09' => esc_html__( 'Isiolo', "ncs-cart" ),
		'KE10' => esc_html__( 'Kajiado', "ncs-cart" ),
		'KE11' => esc_html__( 'Kakamega', "ncs-cart" ),
		'KE12' => esc_html__( 'Kericho', "ncs-cart" ),
		'KE13' => esc_html__( 'Kiambu', "ncs-cart" ),
		'KE14' => esc_html__( 'Kilifi', "ncs-cart" ),
		'KE15' => esc_html__( 'Kirinyaga', "ncs-cart" ),
		'KE16' => esc_html__( 'Kisii', "ncs-cart" ),
		'KE17' => esc_html__( 'Kisumu', "ncs-cart" ),
		'KE18' => esc_html__( 'Kitui', "ncs-cart" ),
		'KE19' => esc_html__( 'Kwale', "ncs-cart" ),
		'KE20' => esc_html__( 'Laikipia', "ncs-cart" ),
		'KE21' => esc_html__( 'Lamu', "ncs-cart" ),
		'KE22' => esc_html__( 'Machakos', "ncs-cart" ),
		'KE23' => esc_html__( 'Makueni', "ncs-cart" ),
		'KE24' => esc_html__( 'Mandera', "ncs-cart" ),
		'KE25' => esc_html__( 'Marsabit', "ncs-cart" ),
		'KE26' => esc_html__( 'Meru', "ncs-cart" ),
		'KE27' => esc_html__( 'Migori', "ncs-cart" ),
		'KE28' => esc_html__( 'Mombasa', "ncs-cart" ),
		'KE29' => esc_html__( 'Murang’a', "ncs-cart" ),
		'KE30' => esc_html__( 'Nairobi County', "ncs-cart" ),
		'KE31' => esc_html__( 'Nakuru', "ncs-cart" ),
		'KE32' => esc_html__( 'Nandi', "ncs-cart" ),
		'KE33' => esc_html__( 'Narok', "ncs-cart" ),
		'KE34' => esc_html__( 'Nyamira', "ncs-cart" ),
		'KE35' => esc_html__( 'Nyandarua', "ncs-cart" ),
		'KE36' => esc_html__( 'Nyeri', "ncs-cart" ),
		'KE37' => esc_html__( 'Samburu', "ncs-cart" ),
		'KE38' => esc_html__( 'Siaya', "ncs-cart" ),
		'KE39' => esc_html__( 'Taita-Taveta', "ncs-cart" ),
		'KE40' => esc_html__( 'Tana River', "ncs-cart" ),
		'KE41' => esc_html__( 'Tharaka-Nithi', "ncs-cart" ),
		'KE42' => esc_html__( 'Trans Nzoia', "ncs-cart" ),
		'KE43' => esc_html__( 'Turkana', "ncs-cart" ),
		'KE44' => esc_html__( 'Uasin Gishu', "ncs-cart" ),
		'KE45' => esc_html__( 'Vihiga', "ncs-cart" ),
		'KE46' => esc_html__( 'Wajir', "ncs-cart" ),
		'KE47' => esc_html__( 'West Pokot', "ncs-cart" ),
	),
	'KR' => array(),
	'KW' => array(),
	'LA' => array(
		'AT' => esc_html__( 'Attapeu', "ncs-cart" ),
		'BK' => esc_html__( 'Bokeo', "ncs-cart" ),
		'BL' => esc_html__( 'Bolikhamsai', "ncs-cart" ),
		'CH' => esc_html__( 'Champasak', "ncs-cart" ),
		'HO' => esc_html__( 'Houaphanh', "ncs-cart" ),
		'KH' => esc_html__( 'Khammouane', "ncs-cart" ),
		'LM' => esc_html__( 'Luang Namtha', "ncs-cart" ),
		'LP' => esc_html__( 'Luang Prabang', "ncs-cart" ),
		'OU' => esc_html__( 'Oudomxay', "ncs-cart" ),
		'PH' => esc_html__( 'Phongsaly', "ncs-cart" ),
		'SL' => esc_html__( 'Salavan', "ncs-cart" ),
		'SV' => esc_html__( 'Savannakhet', "ncs-cart" ),
		'VI' => esc_html__( 'Vientiane Province', "ncs-cart" ),
		'VT' => esc_html__( 'Vientiane', "ncs-cart" ),
		'XA' => esc_html__( 'Sainyabuli', "ncs-cart" ),
		'XE' => esc_html__( 'Sekong', "ncs-cart" ),
		'XI' => esc_html__( 'Xiangkhouang', "ncs-cart" ),
		'XS' => esc_html__( 'Xaisomboun', "ncs-cart" ),
	),
	'LB' => array(),
	'LR' => array( // Liberia provinces.
		'BM' => esc_html__( 'Bomi', "ncs-cart" ),
		'BN' => esc_html__( 'Bong', "ncs-cart" ),
		'GA' => esc_html__( 'Gbarpolu', "ncs-cart" ),
		'GB' => esc_html__( 'Grand Bassa', "ncs-cart" ),
		'GC' => esc_html__( 'Grand Cape Mount', "ncs-cart" ),
		'GG' => esc_html__( 'Grand Gedeh', "ncs-cart" ),
		'GK' => esc_html__( 'Grand Kru', "ncs-cart" ),
		'LO' => esc_html__( 'Lofa', "ncs-cart" ),
		'MA' => esc_html__( 'Margibi', "ncs-cart" ),
		'MY' => esc_html__( 'Maryland', "ncs-cart" ),
		'MO' => esc_html__( 'Montserrado', "ncs-cart" ),
		'NM' => esc_html__( 'Nimba', "ncs-cart" ),
		'RV' => esc_html__( 'Rivercess', "ncs-cart" ),
		'RG' => esc_html__( 'River Gee', "ncs-cart" ),
		'SN' => esc_html__( 'Sinoe', "ncs-cart" ),
	),
	'LU' => array(),
	'MD' => array( // Moldova states.
		'C'  => esc_html__( 'Chișinău', "ncs-cart" ),
		'BL' => esc_html__( 'Bălți', "ncs-cart" ),
		'AN' => esc_html__( 'Anenii Noi', "ncs-cart" ),
		'BS' => esc_html__( 'Basarabeasca', "ncs-cart" ),
		'BR' => esc_html__( 'Briceni', "ncs-cart" ),
		'CH' => esc_html__( 'Cahul', "ncs-cart" ),
		'CT' => esc_html__( 'Cantemir', "ncs-cart" ),
		'CL' => esc_html__( 'Călărași', "ncs-cart" ),
		'CS' => esc_html__( 'Căușeni', "ncs-cart" ),
		'CM' => esc_html__( 'Cimișlia', "ncs-cart" ),
		'CR' => esc_html__( 'Criuleni', "ncs-cart" ),
		'DN' => esc_html__( 'Dondușeni', "ncs-cart" ),
		'DR' => esc_html__( 'Drochia', "ncs-cart" ),
		'DB' => esc_html__( 'Dubăsari', "ncs-cart" ),
		'ED' => esc_html__( 'Edineț', "ncs-cart" ),
		'FL' => esc_html__( 'Fălești', "ncs-cart" ),
		'FR' => esc_html__( 'Florești', "ncs-cart" ),
		'GE' => esc_html__( 'UTA Găgăuzia', "ncs-cart" ),
		'GL' => esc_html__( 'Glodeni', "ncs-cart" ),
		'HN' => esc_html__( 'Hîncești', "ncs-cart" ),
		'IL' => esc_html__( 'Ialoveni', "ncs-cart" ),
		'LV' => esc_html__( 'Leova', "ncs-cart" ),
		'NS' => esc_html__( 'Nisporeni', "ncs-cart" ),
		'OC' => esc_html__( 'Ocnița', "ncs-cart" ),
		'OR' => esc_html__( 'Orhei', "ncs-cart" ),
		'RZ' => esc_html__( 'Rezina', "ncs-cart" ),
		'RS' => esc_html__( 'Rîșcani', "ncs-cart" ),
		'SG' => esc_html__( 'Sîngerei', "ncs-cart" ),
		'SR' => esc_html__( 'Soroca', "ncs-cart" ),
		'ST' => esc_html__( 'Strășeni', "ncs-cart" ),
		'SD' => esc_html__( 'Șoldănești', "ncs-cart" ),
		'SV' => esc_html__( 'Ștefan Vodă', "ncs-cart" ),
		'TR' => esc_html__( 'Taraclia', "ncs-cart" ),
		'TL' => esc_html__( 'Telenești', "ncs-cart" ),
		'UN' => esc_html__( 'Ungheni', "ncs-cart" ),
	),
	'MQ' => array(),
	'MT' => array(),
	'MX' => array( // Mexico States.
		'DF' => esc_html__( 'Ciudad de México', "ncs-cart" ),
		'JA' => esc_html__( 'Jalisco', "ncs-cart" ),
		'NL' => esc_html__( 'Nuevo León', "ncs-cart" ),
		'AG' => esc_html__( 'Aguascalientes', "ncs-cart" ),
		'BC' => esc_html__( 'Baja California', "ncs-cart" ),
		'BS' => esc_html__( 'Baja California Sur', "ncs-cart" ),
		'CM' => esc_html__( 'Campeche', "ncs-cart" ),
		'CS' => esc_html__( 'Chiapas', "ncs-cart" ),
		'CH' => esc_html__( 'Chihuahua', "ncs-cart" ),
		'CO' => esc_html__( 'Coahuila', "ncs-cart" ),
		'CL' => esc_html__( 'Colima', "ncs-cart" ),
		'DG' => esc_html__( 'Durango', "ncs-cart" ),
		'GT' => esc_html__( 'Guanajuato', "ncs-cart" ),
		'GR' => esc_html__( 'Guerrero', "ncs-cart" ),
		'HG' => esc_html__( 'Hidalgo', "ncs-cart" ),
		'MX' => esc_html__( 'Estado de México', "ncs-cart" ),
		'MI' => esc_html__( 'Michoacán', "ncs-cart" ),
		'MO' => esc_html__( 'Morelos', "ncs-cart" ),
		'NA' => esc_html__( 'Nayarit', "ncs-cart" ),
		'OA' => esc_html__( 'Oaxaca', "ncs-cart" ),
		'PU' => esc_html__( 'Puebla', "ncs-cart" ),
		'QT' => esc_html__( 'Querétaro', "ncs-cart" ),
		'QR' => esc_html__( 'Quintana Roo', "ncs-cart" ),
		'SL' => esc_html__( 'San Luis Potosí', "ncs-cart" ),
		'SI' => esc_html__( 'Sinaloa', "ncs-cart" ),
		'SO' => esc_html__( 'Sonora', "ncs-cart" ),
		'TB' => esc_html__( 'Tabasco', "ncs-cart" ),
		'TM' => esc_html__( 'Tamaulipas', "ncs-cart" ),
		'TL' => esc_html__( 'Tlaxcala', "ncs-cart" ),
		'VE' => esc_html__( 'Veracruz', "ncs-cart" ),
		'YU' => esc_html__( 'Yucatán', "ncs-cart" ),
		'ZA' => esc_html__( 'Zacatecas', "ncs-cart" ),
	),
	'MY' => array( // Malaysian states.
		'JHR' => esc_html__( 'Johor', "ncs-cart" ),
		'KDH' => esc_html__( 'Kedah', "ncs-cart" ),
		'KTN' => esc_html__( 'Kelantan', "ncs-cart" ),
		'LBN' => esc_html__( 'Labuan', "ncs-cart" ),
		'MLK' => esc_html__( 'Malacca (Melaka)', "ncs-cart" ),
		'NSN' => esc_html__( 'Negeri Sembilan', "ncs-cart" ),
		'PHG' => esc_html__( 'Pahang', "ncs-cart" ),
		'PNG' => esc_html__( 'Penang (Pulau Pinang)', "ncs-cart" ),
		'PRK' => esc_html__( 'Perak', "ncs-cart" ),
		'PLS' => esc_html__( 'Perlis', "ncs-cart" ),
		'SBH' => esc_html__( 'Sabah', "ncs-cart" ),
		'SWK' => esc_html__( 'Sarawak', "ncs-cart" ),
		'SGR' => esc_html__( 'Selangor', "ncs-cart" ),
		'TRG' => esc_html__( 'Terengganu', "ncs-cart" ),
		'PJY' => esc_html__( 'Putrajaya', "ncs-cart" ),
		'KUL' => esc_html__( 'Kuala Lumpur', "ncs-cart" ),
	),
	'MZ' => array( // Mozambique provinces.
		'MZP'   => esc_html__( 'Cabo Delgado', "ncs-cart" ),
		'MZG'   => esc_html__( 'Gaza', "ncs-cart" ),
		'MZI'   => esc_html__( 'Inhambane', "ncs-cart" ),
		'MZB'   => esc_html__( 'Manica', "ncs-cart" ),
		'MZL'   => esc_html__( 'Maputo Province', "ncs-cart" ),
		'MZMPM' => esc_html__( 'Maputo', "ncs-cart" ),
		'MZN'   => esc_html__( 'Nampula', "ncs-cart" ),
		'MZA'   => esc_html__( 'Niassa', "ncs-cart" ),
		'MZS'   => esc_html__( 'Sofala', "ncs-cart" ),
		'MZT'   => esc_html__( 'Tete', "ncs-cart" ),
		'MZQ'   => esc_html__( 'Zambézia', "ncs-cart" ),
	),
	'NA' => array( // Namibia regions.
		'ER' => esc_html__( 'Erongo', "ncs-cart" ),
		'HA' => esc_html__( 'Hardap', "ncs-cart" ),
		'KA' => esc_html__( 'Karas', "ncs-cart" ),
		'KE' => esc_html__( 'Kavango East', "ncs-cart" ),
		'KW' => esc_html__( 'Kavango West', "ncs-cart" ),
		'KH' => esc_html__( 'Khomas', "ncs-cart" ),
		'KU' => esc_html__( 'Kunene', "ncs-cart" ),
		'OW' => esc_html__( 'Ohangwena', "ncs-cart" ),
		'OH' => esc_html__( 'Omaheke', "ncs-cart" ),
		'OS' => esc_html__( 'Omusati', "ncs-cart" ),
		'ON' => esc_html__( 'Oshana', "ncs-cart" ),
		'OT' => esc_html__( 'Oshikoto', "ncs-cart" ),
		'OD' => esc_html__( 'Otjozondjupa', "ncs-cart" ),
		'CA' => esc_html__( 'Zambezi', "ncs-cart" ),
	),
	'NG' => array( // Nigerian provinces.
		'AB' => esc_html__( 'Abia', "ncs-cart" ),
		'FC' => esc_html__( 'Abuja', "ncs-cart" ),
		'AD' => esc_html__( 'Adamawa', "ncs-cart" ),
		'AK' => esc_html__( 'Akwa Ibom', "ncs-cart" ),
		'AN' => esc_html__( 'Anambra', "ncs-cart" ),
		'BA' => esc_html__( 'Bauchi', "ncs-cart" ),
		'BY' => esc_html__( 'Bayelsa', "ncs-cart" ),
		'BE' => esc_html__( 'Benue', "ncs-cart" ),
		'BO' => esc_html__( 'Borno', "ncs-cart" ),
		'CR' => esc_html__( 'Cross River', "ncs-cart" ),
		'DE' => esc_html__( 'Delta', "ncs-cart" ),
		'EB' => esc_html__( 'Ebonyi', "ncs-cart" ),
		'ED' => esc_html__( 'Edo', "ncs-cart" ),
		'EK' => esc_html__( 'Ekiti', "ncs-cart" ),
		'EN' => esc_html__( 'Enugu', "ncs-cart" ),
		'GO' => esc_html__( 'Gombe', "ncs-cart" ),
		'IM' => esc_html__( 'Imo', "ncs-cart" ),
		'JI' => esc_html__( 'Jigawa', "ncs-cart" ),
		'KD' => esc_html__( 'Kaduna', "ncs-cart" ),
		'KN' => esc_html__( 'Kano', "ncs-cart" ),
		'KT' => esc_html__( 'Katsina', "ncs-cart" ),
		'KE' => esc_html__( 'Kebbi', "ncs-cart" ),
		'KO' => esc_html__( 'Kogi', "ncs-cart" ),
		'KW' => esc_html__( 'Kwara', "ncs-cart" ),
		'LA' => esc_html__( 'Lagos', "ncs-cart" ),
		'NA' => esc_html__( 'Nasarawa', "ncs-cart" ),
		'NI' => esc_html__( 'Niger', "ncs-cart" ),
		'OG' => esc_html__( 'Ogun', "ncs-cart" ),
		'ON' => esc_html__( 'Ondo', "ncs-cart" ),
		'OS' => esc_html__( 'Osun', "ncs-cart" ),
		'OY' => esc_html__( 'Oyo', "ncs-cart" ),
		'PL' => esc_html__( 'Plateau', "ncs-cart" ),
		'RI' => esc_html__( 'Rivers', "ncs-cart" ),
		'SO' => esc_html__( 'Sokoto', "ncs-cart" ),
		'TA' => esc_html__( 'Taraba', "ncs-cart" ),
		'YO' => esc_html__( 'Yobe', "ncs-cart" ),
		'ZA' => esc_html__( 'Zamfara', "ncs-cart" ),
	),
	'NL' => array(),
	'NO' => array(),
	'NP' => array( // Nepal states (Zones).
		'BAG' => esc_html__( 'Bagmati', "ncs-cart" ),
		'BHE' => esc_html__( 'Bheri', "ncs-cart" ),
		'DHA' => esc_html__( 'Dhaulagiri', "ncs-cart" ),
		'GAN' => esc_html__( 'Gandaki', "ncs-cart" ),
		'JAN' => esc_html__( 'Janakpur', "ncs-cart" ),
		'KAR' => esc_html__( 'Karnali', "ncs-cart" ),
		'KOS' => esc_html__( 'Koshi', "ncs-cart" ),
		'LUM' => esc_html__( 'Lumbini', "ncs-cart" ),
		'MAH' => esc_html__( 'Mahakali', "ncs-cart" ),
		'MEC' => esc_html__( 'Mechi', "ncs-cart" ),
		'NAR' => esc_html__( 'Narayani', "ncs-cart" ),
		'RAP' => esc_html__( 'Rapti', "ncs-cart" ),
		'SAG' => esc_html__( 'Sagarmatha', "ncs-cart" ),
		'SET' => esc_html__( 'Seti', "ncs-cart" ),
	),
	'NZ' => array( // New Zealand States.
		'NL' => esc_html__( 'Northland', "ncs-cart" ),
		'AK' => esc_html__( 'Auckland', "ncs-cart" ),
		'WA' => esc_html__( 'Waikato', "ncs-cart" ),
		'BP' => esc_html__( 'Bay of Plenty', "ncs-cart" ),
		'TK' => esc_html__( 'Taranaki', "ncs-cart" ),
		'GI' => esc_html__( 'Gisborne', "ncs-cart" ),
		'HB' => esc_html__( 'Hawke’s Bay', "ncs-cart" ),
		'MW' => esc_html__( 'Manawatu-Wanganui', "ncs-cart" ),
		'WE' => esc_html__( 'Wellington', "ncs-cart" ),
		'NS' => esc_html__( 'Nelson', "ncs-cart" ),
		'MB' => esc_html__( 'Marlborough', "ncs-cart" ),
		'TM' => esc_html__( 'Tasman', "ncs-cart" ),
		'WC' => esc_html__( 'West Coast', "ncs-cart" ),
		'CT' => esc_html__( 'Canterbury', "ncs-cart" ),
		'OT' => esc_html__( 'Otago', "ncs-cart" ),
		'SL' => esc_html__( 'Southland', "ncs-cart" ),
	),
	'PE' => array( // Peru states.
		'CAL' => esc_html__( 'El Callao', "ncs-cart" ),
		'LMA' => esc_html__( 'Municipalidad Metropolitana de Lima', "ncs-cart" ),
		'AMA' => esc_html__( 'Amazonas', "ncs-cart" ),
		'ANC' => esc_html__( 'Ancash', "ncs-cart" ),
		'APU' => esc_html__( 'Apurímac', "ncs-cart" ),
		'ARE' => esc_html__( 'Arequipa', "ncs-cart" ),
		'AYA' => esc_html__( 'Ayacucho', "ncs-cart" ),
		'CAJ' => esc_html__( 'Cajamarca', "ncs-cart" ),
		'CUS' => esc_html__( 'Cusco', "ncs-cart" ),
		'HUV' => esc_html__( 'Huancavelica', "ncs-cart" ),
		'HUC' => esc_html__( 'Huánuco', "ncs-cart" ),
		'ICA' => esc_html__( 'Ica', "ncs-cart" ),
		'JUN' => esc_html__( 'Junín', "ncs-cart" ),
		'LAL' => esc_html__( 'La Libertad', "ncs-cart" ),
		'LAM' => esc_html__( 'Lambayeque', "ncs-cart" ),
		'LIM' => esc_html__( 'Lima', "ncs-cart" ),
		'LOR' => esc_html__( 'Loreto', "ncs-cart" ),
		'MDD' => esc_html__( 'Madre de Dios', "ncs-cart" ),
		'MOQ' => esc_html__( 'Moquegua', "ncs-cart" ),
		'PAS' => esc_html__( 'Pasco', "ncs-cart" ),
		'PIU' => esc_html__( 'Piura', "ncs-cart" ),
		'PUN' => esc_html__( 'Puno', "ncs-cart" ),
		'SAM' => esc_html__( 'San Martín', "ncs-cart" ),
		'TAC' => esc_html__( 'Tacna', "ncs-cart" ),
		'TUM' => esc_html__( 'Tumbes', "ncs-cart" ),
		'UCA' => esc_html__( 'Ucayali', "ncs-cart" ),
	),

	/**
	 * Philippine Provinces.
	 */
	'PH' => array(
		'ABR' => esc_html__( 'Abra', "ncs-cart" ),
		'AGN' => esc_html__( 'Agusan del Norte', "ncs-cart" ),
		'AGS' => esc_html__( 'Agusan del Sur', "ncs-cart" ),
		'AKL' => esc_html__( 'Aklan', "ncs-cart" ),
		'ALB' => esc_html__( 'Albay', "ncs-cart" ),
		'ANT' => esc_html__( 'Antique', "ncs-cart" ),
		'APA' => esc_html__( 'Apayao', "ncs-cart" ),
		'AUR' => esc_html__( 'Aurora', "ncs-cart" ),
		'BAS' => esc_html__( 'Basilan', "ncs-cart" ),
		'BAN' => esc_html__( 'Bataan', "ncs-cart" ),
		'BTN' => esc_html__( 'Batanes', "ncs-cart" ),
		'BTG' => esc_html__( 'Batangas', "ncs-cart" ),
		'BEN' => esc_html__( 'Benguet', "ncs-cart" ),
		'BIL' => esc_html__( 'Biliran', "ncs-cart" ),
		'BOH' => esc_html__( 'Bohol', "ncs-cart" ),
		'BUK' => esc_html__( 'Bukidnon', "ncs-cart" ),
		'BUL' => esc_html__( 'Bulacan', "ncs-cart" ),
		'CAG' => esc_html__( 'Cagayan', "ncs-cart" ),
		'CAN' => esc_html__( 'Camarines Norte', "ncs-cart" ),
		'CAS' => esc_html__( 'Camarines Sur', "ncs-cart" ),
		'CAM' => esc_html__( 'Camiguin', "ncs-cart" ),
		'CAP' => esc_html__( 'Capiz', "ncs-cart" ),
		'CAT' => esc_html__( 'Catanduanes', "ncs-cart" ),
		'CAV' => esc_html__( 'Cavite', "ncs-cart" ),
		'CEB' => esc_html__( 'Cebu', "ncs-cart" ),
		'COM' => esc_html__( 'Compostela Valley', "ncs-cart" ),
		'NCO' => esc_html__( 'Cotabato', "ncs-cart" ),
		'DAV' => esc_html__( 'Davao del Norte', "ncs-cart" ),
		'DAS' => esc_html__( 'Davao del Sur', "ncs-cart" ),
		'DAC' => esc_html__( 'Davao Occidental', "ncs-cart" ),
		'DAO' => esc_html__( 'Davao Oriental', "ncs-cart" ),
		'DIN' => esc_html__( 'Dinagat Islands', "ncs-cart" ),
		'EAS' => esc_html__( 'Eastern Samar', "ncs-cart" ),
		'GUI' => esc_html__( 'Guimaras', "ncs-cart" ),
		'IFU' => esc_html__( 'Ifugao', "ncs-cart" ),
		'ILN' => esc_html__( 'Ilocos Norte', "ncs-cart" ),
		'ILS' => esc_html__( 'Ilocos Sur', "ncs-cart" ),
		'ILI' => esc_html__( 'Iloilo', "ncs-cart" ),
		'ISA' => esc_html__( 'Isabela', "ncs-cart" ),
		'KAL' => esc_html__( 'Kalinga', "ncs-cart" ),
		'LUN' => esc_html__( 'La Union', "ncs-cart" ),
		'LAG' => esc_html__( 'Laguna', "ncs-cart" ),
		'LAN' => esc_html__( 'Lanao del Norte', "ncs-cart" ),
		'LAS' => esc_html__( 'Lanao del Sur', "ncs-cart" ),
		'LEY' => esc_html__( 'Leyte', "ncs-cart" ),
		'MAG' => esc_html__( 'Maguindanao', "ncs-cart" ),
		'MAD' => esc_html__( 'Marinduque', "ncs-cart" ),
		'MAS' => esc_html__( 'Masbate', "ncs-cart" ),
		'MSC' => esc_html__( 'Misamis Occidental', "ncs-cart" ),
		'MSR' => esc_html__( 'Misamis Oriental', "ncs-cart" ),
		'MOU' => esc_html__( 'Mountain Province', "ncs-cart" ),
		'NEC' => esc_html__( 'Negros Occidental', "ncs-cart" ),
		'NER' => esc_html__( 'Negros Oriental', "ncs-cart" ),
		'NSA' => esc_html__( 'Northern Samar', "ncs-cart" ),
		'NUE' => esc_html__( 'Nueva Ecija', "ncs-cart" ),
		'NUV' => esc_html__( 'Nueva Vizcaya', "ncs-cart" ),
		'MDC' => esc_html__( 'Occidental Mindoro', "ncs-cart" ),
		'MDR' => esc_html__( 'Oriental Mindoro', "ncs-cart" ),
		'PLW' => esc_html__( 'Palawan', "ncs-cart" ),
		'PAM' => esc_html__( 'Pampanga', "ncs-cart" ),
		'PAN' => esc_html__( 'Pangasinan', "ncs-cart" ),
		'QUE' => esc_html__( 'Quezon', "ncs-cart" ),
		'QUI' => esc_html__( 'Quirino', "ncs-cart" ),
		'RIZ' => esc_html__( 'Rizal', "ncs-cart" ),
		'ROM' => esc_html__( 'Romblon', "ncs-cart" ),
		'WSA' => esc_html__( 'Samar', "ncs-cart" ),
		'SAR' => esc_html__( 'Sarangani', "ncs-cart" ),
		'SIQ' => esc_html__( 'Siquijor', "ncs-cart" ),
		'SOR' => esc_html__( 'Sorsogon', "ncs-cart" ),
		'SCO' => esc_html__( 'South Cotabato', "ncs-cart" ),
		'SLE' => esc_html__( 'Southern Leyte', "ncs-cart" ),
		'SUK' => esc_html__( 'Sultan Kudarat', "ncs-cart" ),
		'SLU' => esc_html__( 'Sulu', "ncs-cart" ),
		'SUN' => esc_html__( 'Surigao del Norte', "ncs-cart" ),
		'SUR' => esc_html__( 'Surigao del Sur', "ncs-cart" ),
		'TAR' => esc_html__( 'Tarlac', "ncs-cart" ),
		'TAW' => esc_html__( 'Tawi-Tawi', "ncs-cart" ),
		'ZMB' => esc_html__( 'Zambales', "ncs-cart" ),
		'ZAN' => esc_html__( 'Zamboanga del Norte', "ncs-cart" ),
		'ZAS' => esc_html__( 'Zamboanga del Sur', "ncs-cart" ),
		'ZSI' => esc_html__( 'Zamboanga Sibugay', "ncs-cart" ),
		'00'  => esc_html__( 'Metro Manila', "ncs-cart" ),
	),
	'PK' => array( // Pakistan's states.
		'JK' => esc_html__( 'Azad Kashmir', "ncs-cart" ),
		'BA' => esc_html__( 'Balochistan', "ncs-cart" ),
		'TA' => esc_html__( 'FATA', "ncs-cart" ),
		'GB' => esc_html__( 'Gilgit Baltistan', "ncs-cart" ),
		'IS' => esc_html__( 'Islamabad Capital Territory', "ncs-cart" ),
		'KP' => esc_html__( 'Khyber Pakhtunkhwa', "ncs-cart" ),
		'PB' => esc_html__( 'Punjab', "ncs-cart" ),
		'SD' => esc_html__( 'Sindh', "ncs-cart" ),
	),
	'PL' => array(),
	'PT' => array(),
	'PY' => array( // Paraguay states.
		'PY-ASU' => esc_html__( 'Asunción', "ncs-cart" ),
		'PY-1'   => esc_html__( 'Concepción', "ncs-cart" ),
		'PY-2'   => esc_html__( 'San Pedro', "ncs-cart" ),
		'PY-3'   => esc_html__( 'Cordillera', "ncs-cart" ),
		'PY-4'   => esc_html__( 'Guairá', "ncs-cart" ),
		'PY-5'   => esc_html__( 'Caaguazú', "ncs-cart" ),
		'PY-6'   => esc_html__( 'Caazapá', "ncs-cart" ),
		'PY-7'   => esc_html__( 'Itapúa', "ncs-cart" ),
		'PY-8'   => esc_html__( 'Misiones', "ncs-cart" ),
		'PY-9'   => esc_html__( 'Paraguarí', "ncs-cart" ),
		'PY-10'  => esc_html__( 'Alto Paraná', "ncs-cart" ),
		'PY-11'  => esc_html__( 'Central', "ncs-cart" ),
		'PY-12'  => esc_html__( 'Ñeembucú', "ncs-cart" ),
		'PY-13'  => esc_html__( 'Amambay', "ncs-cart" ),
		'PY-14'  => esc_html__( 'Canindeyú', "ncs-cart" ),
		'PY-15'  => esc_html__( 'Presidente Hayes', "ncs-cart" ),
		'PY-16'  => esc_html__( 'Alto Paraguay', "ncs-cart" ),
		'PY-17'  => esc_html__( 'Boquerón', "ncs-cart" ),
	),
	'RE' => array(),
	'RO' => array( // Romania states.
		'AB' => esc_html__( 'Alba', "ncs-cart" ),
		'AR' => esc_html__( 'Arad', "ncs-cart" ),
		'AG' => esc_html__( 'Argeș', "ncs-cart" ),
		'BC' => esc_html__( 'Bacău', "ncs-cart" ),
		'BH' => esc_html__( 'Bihor', "ncs-cart" ),
		'BN' => esc_html__( 'Bistrița-Năsăud', "ncs-cart" ),
		'BT' => esc_html__( 'Botoșani', "ncs-cart" ),
		'BR' => esc_html__( 'Brăila', "ncs-cart" ),
		'BV' => esc_html__( 'Brașov', "ncs-cart" ),
		'B'  => esc_html__( 'București', "ncs-cart" ),
		'BZ' => esc_html__( 'Buzău', "ncs-cart" ),
		'CL' => esc_html__( 'Călărași', "ncs-cart" ),
		'CS' => esc_html__( 'Caraș-Severin', "ncs-cart" ),
		'CJ' => esc_html__( 'Cluj', "ncs-cart" ),
		'CT' => esc_html__( 'Constanța', "ncs-cart" ),
		'CV' => esc_html__( 'Covasna', "ncs-cart" ),
		'DB' => esc_html__( 'Dâmbovița', "ncs-cart" ),
		'DJ' => esc_html__( 'Dolj', "ncs-cart" ),
		'GL' => esc_html__( 'Galați', "ncs-cart" ),
		'GR' => esc_html__( 'Giurgiu', "ncs-cart" ),
		'GJ' => esc_html__( 'Gorj', "ncs-cart" ),
		'HR' => esc_html__( 'Harghita', "ncs-cart" ),
		'HD' => esc_html__( 'Hunedoara', "ncs-cart" ),
		'IL' => esc_html__( 'Ialomița', "ncs-cart" ),
		'IS' => esc_html__( 'Iași', "ncs-cart" ),
		'IF' => esc_html__( 'Ilfov', "ncs-cart" ),
		'MM' => esc_html__( 'Maramureș', "ncs-cart" ),
		'MH' => esc_html__( 'Mehedinți', "ncs-cart" ),
		'MS' => esc_html__( 'Mureș', "ncs-cart" ),
		'NT' => esc_html__( 'Neamț', "ncs-cart" ),
		'OT' => esc_html__( 'Olt', "ncs-cart" ),
		'PH' => esc_html__( 'Prahova', "ncs-cart" ),
		'SJ' => esc_html__( 'Sălaj', "ncs-cart" ),
		'SM' => esc_html__( 'Satu Mare', "ncs-cart" ),
		'SB' => esc_html__( 'Sibiu', "ncs-cart" ),
		'SV' => esc_html__( 'Suceava', "ncs-cart" ),
		'TR' => esc_html__( 'Teleorman', "ncs-cart" ),
		'TM' => esc_html__( 'Timiș', "ncs-cart" ),
		'TL' => esc_html__( 'Tulcea', "ncs-cart" ),
		'VL' => esc_html__( 'Vâlcea', "ncs-cart" ),
		'VS' => esc_html__( 'Vaslui', "ncs-cart" ),
		'VN' => esc_html__( 'Vrancea', "ncs-cart" ),
	),
	'RS' => array(),
	'SG' => array(),
	'SK' => array(),
	'SI' => array(),
	'TH' => array( // Thailand states.
		'TH-37' => esc_html__( 'Amnat Charoen', "ncs-cart" ),
		'TH-15' => esc_html__( 'Ang Thong', "ncs-cart" ),
		'TH-14' => esc_html__( 'Ayutthaya', "ncs-cart" ),
		'TH-10' => esc_html__( 'Bangkok', "ncs-cart" ),
		'TH-38' => esc_html__( 'Bueng Kan', "ncs-cart" ),
		'TH-31' => esc_html__( 'Buri Ram', "ncs-cart" ),
		'TH-24' => esc_html__( 'Chachoengsao', "ncs-cart" ),
		'TH-18' => esc_html__( 'Chai Nat', "ncs-cart" ),
		'TH-36' => esc_html__( 'Chaiyaphum', "ncs-cart" ),
		'TH-22' => esc_html__( 'Chanthaburi', "ncs-cart" ),
		'TH-50' => esc_html__( 'Chiang Mai', "ncs-cart" ),
		'TH-57' => esc_html__( 'Chiang Rai', "ncs-cart" ),
		'TH-20' => esc_html__( 'Chonburi', "ncs-cart" ),
		'TH-86' => esc_html__( 'Chumphon', "ncs-cart" ),
		'TH-46' => esc_html__( 'Kalasin', "ncs-cart" ),
		'TH-62' => esc_html__( 'Kamphaeng Phet', "ncs-cart" ),
		'TH-71' => esc_html__( 'Kanchanaburi', "ncs-cart" ),
		'TH-40' => esc_html__( 'Khon Kaen', "ncs-cart" ),
		'TH-81' => esc_html__( 'Krabi', "ncs-cart" ),
		'TH-52' => esc_html__( 'Lampang', "ncs-cart" ),
		'TH-51' => esc_html__( 'Lamphun', "ncs-cart" ),
		'TH-42' => esc_html__( 'Loei', "ncs-cart" ),
		'TH-16' => esc_html__( 'Lopburi', "ncs-cart" ),
		'TH-58' => esc_html__( 'Mae Hong Son', "ncs-cart" ),
		'TH-44' => esc_html__( 'Maha Sarakham', "ncs-cart" ),
		'TH-49' => esc_html__( 'Mukdahan', "ncs-cart" ),
		'TH-26' => esc_html__( 'Nakhon Nayok', "ncs-cart" ),
		'TH-73' => esc_html__( 'Nakhon Pathom', "ncs-cart" ),
		'TH-48' => esc_html__( 'Nakhon Phanom', "ncs-cart" ),
		'TH-30' => esc_html__( 'Nakhon Ratchasima', "ncs-cart" ),
		'TH-60' => esc_html__( 'Nakhon Sawan', "ncs-cart" ),
		'TH-80' => esc_html__( 'Nakhon Si Thammarat', "ncs-cart" ),
		'TH-55' => esc_html__( 'Nan', "ncs-cart" ),
		'TH-96' => esc_html__( 'Narathiwat', "ncs-cart" ),
		'TH-39' => esc_html__( 'Nong Bua Lam Phu', "ncs-cart" ),
		'TH-43' => esc_html__( 'Nong Khai', "ncs-cart" ),
		'TH-12' => esc_html__( 'Nonthaburi', "ncs-cart" ),
		'TH-13' => esc_html__( 'Pathum Thani', "ncs-cart" ),
		'TH-94' => esc_html__( 'Pattani', "ncs-cart" ),
		'TH-82' => esc_html__( 'Phang Nga', "ncs-cart" ),
		'TH-93' => esc_html__( 'Phatthalung', "ncs-cart" ),
		'TH-56' => esc_html__( 'Phayao', "ncs-cart" ),
		'TH-67' => esc_html__( 'Phetchabun', "ncs-cart" ),
		'TH-76' => esc_html__( 'Phetchaburi', "ncs-cart" ),
		'TH-66' => esc_html__( 'Phichit', "ncs-cart" ),
		'TH-65' => esc_html__( 'Phitsanulok', "ncs-cart" ),
		'TH-54' => esc_html__( 'Phrae', "ncs-cart" ),
		'TH-83' => esc_html__( 'Phuket', "ncs-cart" ),
		'TH-25' => esc_html__( 'Prachin Buri', "ncs-cart" ),
		'TH-77' => esc_html__( 'Prachuap Khiri Khan', "ncs-cart" ),
		'TH-85' => esc_html__( 'Ranong', "ncs-cart" ),
		'TH-70' => esc_html__( 'Ratchaburi', "ncs-cart" ),
		'TH-21' => esc_html__( 'Rayong', "ncs-cart" ),
		'TH-45' => esc_html__( 'Roi Et', "ncs-cart" ),
		'TH-27' => esc_html__( 'Sa Kaeo', "ncs-cart" ),
		'TH-47' => esc_html__( 'Sakon Nakhon', "ncs-cart" ),
		'TH-11' => esc_html__( 'Samut Prakan', "ncs-cart" ),
		'TH-74' => esc_html__( 'Samut Sakhon', "ncs-cart" ),
		'TH-75' => esc_html__( 'Samut Songkhram', "ncs-cart" ),
		'TH-19' => esc_html__( 'Saraburi', "ncs-cart" ),
		'TH-91' => esc_html__( 'Satun', "ncs-cart" ),
		'TH-17' => esc_html__( 'Sing Buri', "ncs-cart" ),
		'TH-33' => esc_html__( 'Sisaket', "ncs-cart" ),
		'TH-90' => esc_html__( 'Songkhla', "ncs-cart" ),
		'TH-64' => esc_html__( 'Sukhothai', "ncs-cart" ),
		'TH-72' => esc_html__( 'Suphan Buri', "ncs-cart" ),
		'TH-84' => esc_html__( 'Surat Thani', "ncs-cart" ),
		'TH-32' => esc_html__( 'Surin', "ncs-cart" ),
		'TH-63' => esc_html__( 'Tak', "ncs-cart" ),
		'TH-92' => esc_html__( 'Trang', "ncs-cart" ),
		'TH-23' => esc_html__( 'Trat', "ncs-cart" ),
		'TH-34' => esc_html__( 'Ubon Ratchathani', "ncs-cart" ),
		'TH-41' => esc_html__( 'Udon Thani', "ncs-cart" ),
		'TH-61' => esc_html__( 'Uthai Thani', "ncs-cart" ),
		'TH-53' => esc_html__( 'Uttaradit', "ncs-cart" ),
		'TH-95' => esc_html__( 'Yala', "ncs-cart" ),
		'TH-35' => esc_html__( 'Yasothon', "ncs-cart" ),
	),
	'TR' => array( // Turkey States.
		'TR01' => esc_html__( 'Adana', "ncs-cart" ),
		'TR02' => esc_html__( 'Adıyaman', "ncs-cart" ),
		'TR03' => esc_html__( 'Afyon', "ncs-cart" ),
		'TR04' => esc_html__( 'Ağrı', "ncs-cart" ),
		'TR05' => esc_html__( 'Amasya', "ncs-cart" ),
		'TR06' => esc_html__( 'Ankara', "ncs-cart" ),
		'TR07' => esc_html__( 'Antalya', "ncs-cart" ),
		'TR08' => esc_html__( 'Artvin', "ncs-cart" ),
		'TR09' => esc_html__( 'Aydın', "ncs-cart" ),
		'TR10' => esc_html__( 'Balıkesir', "ncs-cart" ),
		'TR11' => esc_html__( 'Bilecik', "ncs-cart" ),
		'TR12' => esc_html__( 'Bingöl', "ncs-cart" ),
		'TR13' => esc_html__( 'Bitlis', "ncs-cart" ),
		'TR14' => esc_html__( 'Bolu', "ncs-cart" ),
		'TR15' => esc_html__( 'Burdur', "ncs-cart" ),
		'TR16' => esc_html__( 'Bursa', "ncs-cart" ),
		'TR17' => esc_html__( 'Çanakkale', "ncs-cart" ),
		'TR18' => esc_html__( 'Çankırı', "ncs-cart" ),
		'TR19' => esc_html__( 'Çorum', "ncs-cart" ),
		'TR20' => esc_html__( 'Denizli', "ncs-cart" ),
		'TR21' => esc_html__( 'Diyarbakır', "ncs-cart" ),
		'TR22' => esc_html__( 'Edirne', "ncs-cart" ),
		'TR23' => esc_html__( 'Elazığ', "ncs-cart" ),
		'TR24' => esc_html__( 'Erzincan', "ncs-cart" ),
		'TR25' => esc_html__( 'Erzurum', "ncs-cart" ),
		'TR26' => esc_html__( 'Eskişehir', "ncs-cart" ),
		'TR27' => esc_html__( 'Gaziantep', "ncs-cart" ),
		'TR28' => esc_html__( 'Giresun', "ncs-cart" ),
		'TR29' => esc_html__( 'Gümüşhane', "ncs-cart" ),
		'TR30' => esc_html__( 'Hakkari', "ncs-cart" ),
		'TR31' => esc_html__( 'Hatay', "ncs-cart" ),
		'TR32' => esc_html__( 'Isparta', "ncs-cart" ),
		'TR33' => esc_html__( 'İçel', "ncs-cart" ),
		'TR34' => esc_html__( 'İstanbul', "ncs-cart" ),
		'TR35' => esc_html__( 'İzmir', "ncs-cart" ),
		'TR36' => esc_html__( 'Kars', "ncs-cart" ),
		'TR37' => esc_html__( 'Kastamonu', "ncs-cart" ),
		'TR38' => esc_html__( 'Kayseri', "ncs-cart" ),
		'TR39' => esc_html__( 'Kırklareli', "ncs-cart" ),
		'TR40' => esc_html__( 'Kırşehir', "ncs-cart" ),
		'TR41' => esc_html__( 'Kocaeli', "ncs-cart" ),
		'TR42' => esc_html__( 'Konya', "ncs-cart" ),
		'TR43' => esc_html__( 'Kütahya', "ncs-cart" ),
		'TR44' => esc_html__( 'Malatya', "ncs-cart" ),
		'TR45' => esc_html__( 'Manisa', "ncs-cart" ),
		'TR46' => esc_html__( 'Kahramanmaraş', "ncs-cart" ),
		'TR47' => esc_html__( 'Mardin', "ncs-cart" ),
		'TR48' => esc_html__( 'Muğla', "ncs-cart" ),
		'TR49' => esc_html__( 'Muş', "ncs-cart" ),
		'TR50' => esc_html__( 'Nevşehir', "ncs-cart" ),
		'TR51' => esc_html__( 'Niğde', "ncs-cart" ),
		'TR52' => esc_html__( 'Ordu', "ncs-cart" ),
		'TR53' => esc_html__( 'Rize', "ncs-cart" ),
		'TR54' => esc_html__( 'Sakarya', "ncs-cart" ),
		'TR55' => esc_html__( 'Samsun', "ncs-cart" ),
		'TR56' => esc_html__( 'Siirt', "ncs-cart" ),
		'TR57' => esc_html__( 'Sinop', "ncs-cart" ),
		'TR58' => esc_html__( 'Sivas', "ncs-cart" ),
		'TR59' => esc_html__( 'Tekirdağ', "ncs-cart" ),
		'TR60' => esc_html__( 'Tokat', "ncs-cart" ),
		'TR61' => esc_html__( 'Trabzon', "ncs-cart" ),
		'TR62' => esc_html__( 'Tunceli', "ncs-cart" ),
		'TR63' => esc_html__( 'Şanlıurfa', "ncs-cart" ),
		'TR64' => esc_html__( 'Uşak', "ncs-cart" ),
		'TR65' => esc_html__( 'Van', "ncs-cart" ),
		'TR66' => esc_html__( 'Yozgat', "ncs-cart" ),
		'TR67' => esc_html__( 'Zonguldak', "ncs-cart" ),
		'TR68' => esc_html__( 'Aksaray', "ncs-cart" ),
		'TR69' => esc_html__( 'Bayburt', "ncs-cart" ),
		'TR70' => esc_html__( 'Karaman', "ncs-cart" ),
		'TR71' => esc_html__( 'Kırıkkale', "ncs-cart" ),
		'TR72' => esc_html__( 'Batman', "ncs-cart" ),
		'TR73' => esc_html__( 'Şırnak', "ncs-cart" ),
		'TR74' => esc_html__( 'Bartın', "ncs-cart" ),
		'TR75' => esc_html__( 'Ardahan', "ncs-cart" ),
		'TR76' => esc_html__( 'Iğdır', "ncs-cart" ),
		'TR77' => esc_html__( 'Yalova', "ncs-cart" ),
		'TR78' => esc_html__( 'Karabük', "ncs-cart" ),
		'TR79' => esc_html__( 'Kilis', "ncs-cart" ),
		'TR80' => esc_html__( 'Osmaniye', "ncs-cart" ),
		'TR81' => esc_html__( 'Düzce', "ncs-cart" ),
	),
	'TZ' => array( // Tanzania States.
		'TZ01' => esc_html__( 'Arusha', "ncs-cart" ),
		'TZ02' => esc_html__( 'Dar es Salaam', "ncs-cart" ),
		'TZ03' => esc_html__( 'Dodoma', "ncs-cart" ),
		'TZ04' => esc_html__( 'Iringa', "ncs-cart" ),
		'TZ05' => esc_html__( 'Kagera', "ncs-cart" ),
		'TZ06' => esc_html__( 'Pemba North', "ncs-cart" ),
		'TZ07' => esc_html__( 'Zanzibar North', "ncs-cart" ),
		'TZ08' => esc_html__( 'Kigoma', "ncs-cart" ),
		'TZ09' => esc_html__( 'Kilimanjaro', "ncs-cart" ),
		'TZ10' => esc_html__( 'Pemba South', "ncs-cart" ),
		'TZ11' => esc_html__( 'Zanzibar South', "ncs-cart" ),
		'TZ12' => esc_html__( 'Lindi', "ncs-cart" ),
		'TZ13' => esc_html__( 'Mara', "ncs-cart" ),
		'TZ14' => esc_html__( 'Mbeya', "ncs-cart" ),
		'TZ15' => esc_html__( 'Zanzibar West', "ncs-cart" ),
		'TZ16' => esc_html__( 'Morogoro', "ncs-cart" ),
		'TZ17' => esc_html__( 'Mtwara', "ncs-cart" ),
		'TZ18' => esc_html__( 'Mwanza', "ncs-cart" ),
		'TZ19' => esc_html__( 'Coast', "ncs-cart" ),
		'TZ20' => esc_html__( 'Rukwa', "ncs-cart" ),
		'TZ21' => esc_html__( 'Ruvuma', "ncs-cart" ),
		'TZ22' => esc_html__( 'Shinyanga', "ncs-cart" ),
		'TZ23' => esc_html__( 'Singida', "ncs-cart" ),
		'TZ24' => esc_html__( 'Tabora', "ncs-cart" ),
		'TZ25' => esc_html__( 'Tanga', "ncs-cart" ),
		'TZ26' => esc_html__( 'Manyara', "ncs-cart" ),
		'TZ27' => esc_html__( 'Geita', "ncs-cart" ),
		'TZ28' => esc_html__( 'Katavi', "ncs-cart" ),
		'TZ29' => esc_html__( 'Njombe', "ncs-cart" ),
		'TZ30' => esc_html__( 'Simiyu', "ncs-cart" ),
	),
	'LK' => array(),
	'SE' => array(),
	'UG' => array( // Uganda districts. Ref: https://en.wikipedia.org/wiki/ISO_3166-2:UG.
		'UG314' => esc_html__( 'Abim', "ncs-cart" ),
		'UG301' => esc_html__( 'Adjumani', "ncs-cart" ),
		'UG322' => esc_html__( 'Agago', "ncs-cart" ),
		'UG323' => esc_html__( 'Alebtong', "ncs-cart" ),
		'UG315' => esc_html__( 'Amolatar', "ncs-cart" ),
		'UG324' => esc_html__( 'Amudat', "ncs-cart" ),
		'UG216' => esc_html__( 'Amuria', "ncs-cart" ),
		'UG316' => esc_html__( 'Amuru', "ncs-cart" ),
		'UG302' => esc_html__( 'Apac', "ncs-cart" ),
		'UG303' => esc_html__( 'Arua', "ncs-cart" ),
		'UG217' => esc_html__( 'Budaka', "ncs-cart" ),
		'UG218' => esc_html__( 'Bududa', "ncs-cart" ),
		'UG201' => esc_html__( 'Bugiri', "ncs-cart" ),
		'UG235' => esc_html__( 'Bugweri', "ncs-cart" ),
		'UG420' => esc_html__( 'Buhweju', "ncs-cart" ),
		'UG117' => esc_html__( 'Buikwe', "ncs-cart" ),
		'UG219' => esc_html__( 'Bukedea', "ncs-cart" ),
		'UG118' => esc_html__( 'Bukomansimbi', "ncs-cart" ),
		'UG220' => esc_html__( 'Bukwa', "ncs-cart" ),
		'UG225' => esc_html__( 'Bulambuli', "ncs-cart" ),
		'UG416' => esc_html__( 'Buliisa', "ncs-cart" ),
		'UG401' => esc_html__( 'Bundibugyo', "ncs-cart" ),
		'UG430' => esc_html__( 'Bunyangabu', "ncs-cart" ),
		'UG402' => esc_html__( 'Bushenyi', "ncs-cart" ),
		'UG202' => esc_html__( 'Busia', "ncs-cart" ),
		'UG221' => esc_html__( 'Butaleja', "ncs-cart" ),
		'UG119' => esc_html__( 'Butambala', "ncs-cart" ),
		'UG233' => esc_html__( 'Butebo', "ncs-cart" ),
		'UG120' => esc_html__( 'Buvuma', "ncs-cart" ),
		'UG226' => esc_html__( 'Buyende', "ncs-cart" ),
		'UG317' => esc_html__( 'Dokolo', "ncs-cart" ),
		'UG121' => esc_html__( 'Gomba', "ncs-cart" ),
		'UG304' => esc_html__( 'Gulu', "ncs-cart" ),
		'UG403' => esc_html__( 'Hoima', "ncs-cart" ),
		'UG417' => esc_html__( 'Ibanda', "ncs-cart" ),
		'UG203' => esc_html__( 'Iganga', "ncs-cart" ),
		'UG418' => esc_html__( 'Isingiro', "ncs-cart" ),
		'UG204' => esc_html__( 'Jinja', "ncs-cart" ),
		'UG318' => esc_html__( 'Kaabong', "ncs-cart" ),
		'UG404' => esc_html__( 'Kabale', "ncs-cart" ),
		'UG405' => esc_html__( 'Kabarole', "ncs-cart" ),
		'UG213' => esc_html__( 'Kaberamaido', "ncs-cart" ),
		'UG427' => esc_html__( 'Kagadi', "ncs-cart" ),
		'UG428' => esc_html__( 'Kakumiro', "ncs-cart" ),
		'UG101' => esc_html__( 'Kalangala', "ncs-cart" ),
		'UG222' => esc_html__( 'Kaliro', "ncs-cart" ),
		'UG122' => esc_html__( 'Kalungu', "ncs-cart" ),
		'UG102' => esc_html__( 'Kampala', "ncs-cart" ),
		'UG205' => esc_html__( 'Kamuli', "ncs-cart" ),
		'UG413' => esc_html__( 'Kamwenge', "ncs-cart" ),
		'UG414' => esc_html__( 'Kanungu', "ncs-cart" ),
		'UG206' => esc_html__( 'Kapchorwa', "ncs-cart" ),
		'UG236' => esc_html__( 'Kapelebyong', "ncs-cart" ),
		'UG126' => esc_html__( 'Kasanda', "ncs-cart" ),
		'UG406' => esc_html__( 'Kasese', "ncs-cart" ),
		'UG207' => esc_html__( 'Katakwi', "ncs-cart" ),
		'UG112' => esc_html__( 'Kayunga', "ncs-cart" ),
		'UG407' => esc_html__( 'Kibaale', "ncs-cart" ),
		'UG103' => esc_html__( 'Kiboga', "ncs-cart" ),
		'UG227' => esc_html__( 'Kibuku', "ncs-cart" ),
		'UG432' => esc_html__( 'Kikuube', "ncs-cart" ),
		'UG419' => esc_html__( 'Kiruhura', "ncs-cart" ),
		'UG421' => esc_html__( 'Kiryandongo', "ncs-cart" ),
		'UG408' => esc_html__( 'Kisoro', "ncs-cart" ),
		'UG305' => esc_html__( 'Kitgum', "ncs-cart" ),
		'UG319' => esc_html__( 'Koboko', "ncs-cart" ),
		'UG325' => esc_html__( 'Kole', "ncs-cart" ),
		'UG306' => esc_html__( 'Kotido', "ncs-cart" ),
		'UG208' => esc_html__( 'Kumi', "ncs-cart" ),
		'UG333' => esc_html__( 'Kwania', "ncs-cart" ),
		'UG228' => esc_html__( 'Kween', "ncs-cart" ),
		'UG123' => esc_html__( 'Kyankwanzi', "ncs-cart" ),
		'UG422' => esc_html__( 'Kyegegwa', "ncs-cart" ),
		'UG415' => esc_html__( 'Kyenjojo', "ncs-cart" ),
		'UG125' => esc_html__( 'Kyotera', "ncs-cart" ),
		'UG326' => esc_html__( 'Lamwo', "ncs-cart" ),
		'UG307' => esc_html__( 'Lira', "ncs-cart" ),
		'UG229' => esc_html__( 'Luuka', "ncs-cart" ),
		'UG104' => esc_html__( 'Luwero', "ncs-cart" ),
		'UG124' => esc_html__( 'Lwengo', "ncs-cart" ),
		'UG114' => esc_html__( 'Lyantonde', "ncs-cart" ),
		'UG223' => esc_html__( 'Manafwa', "ncs-cart" ),
		'UG320' => esc_html__( 'Maracha', "ncs-cart" ),
		'UG105' => esc_html__( 'Masaka', "ncs-cart" ),
		'UG409' => esc_html__( 'Masindi', "ncs-cart" ),
		'UG214' => esc_html__( 'Mayuge', "ncs-cart" ),
		'UG209' => esc_html__( 'Mbale', "ncs-cart" ),
		'UG410' => esc_html__( 'Mbarara', "ncs-cart" ),
		'UG423' => esc_html__( 'Mitooma', "ncs-cart" ),
		'UG115' => esc_html__( 'Mityana', "ncs-cart" ),
		'UG308' => esc_html__( 'Moroto', "ncs-cart" ),
		'UG309' => esc_html__( 'Moyo', "ncs-cart" ),
		'UG106' => esc_html__( 'Mpigi', "ncs-cart" ),
		'UG107' => esc_html__( 'Mubende', "ncs-cart" ),
		'UG108' => esc_html__( 'Mukono', "ncs-cart" ),
		'UG334' => esc_html__( 'Nabilatuk', "ncs-cart" ),
		'UG311' => esc_html__( 'Nakapiripirit', "ncs-cart" ),
		'UG116' => esc_html__( 'Nakaseke', "ncs-cart" ),
		'UG109' => esc_html__( 'Nakasongola', "ncs-cart" ),
		'UG230' => esc_html__( 'Namayingo', "ncs-cart" ),
		'UG234' => esc_html__( 'Namisindwa', "ncs-cart" ),
		'UG224' => esc_html__( 'Namutumba', "ncs-cart" ),
		'UG327' => esc_html__( 'Napak', "ncs-cart" ),
		'UG310' => esc_html__( 'Nebbi', "ncs-cart" ),
		'UG231' => esc_html__( 'Ngora', "ncs-cart" ),
		'UG424' => esc_html__( 'Ntoroko', "ncs-cart" ),
		'UG411' => esc_html__( 'Ntungamo', "ncs-cart" ),
		'UG328' => esc_html__( 'Nwoya', "ncs-cart" ),
		'UG331' => esc_html__( 'Omoro', "ncs-cart" ),
		'UG329' => esc_html__( 'Otuke', "ncs-cart" ),
		'UG321' => esc_html__( 'Oyam', "ncs-cart" ),
		'UG312' => esc_html__( 'Pader', "ncs-cart" ),
		'UG332' => esc_html__( 'Pakwach', "ncs-cart" ),
		'UG210' => esc_html__( 'Pallisa', "ncs-cart" ),
		'UG110' => esc_html__( 'Rakai', "ncs-cart" ),
		'UG429' => esc_html__( 'Rubanda', "ncs-cart" ),
		'UG425' => esc_html__( 'Rubirizi', "ncs-cart" ),
		'UG431' => esc_html__( 'Rukiga', "ncs-cart" ),
		'UG412' => esc_html__( 'Rukungiri', "ncs-cart" ),
		'UG111' => esc_html__( 'Sembabule', "ncs-cart" ),
		'UG232' => esc_html__( 'Serere', "ncs-cart" ),
		'UG426' => esc_html__( 'Sheema', "ncs-cart" ),
		'UG215' => esc_html__( 'Sironko', "ncs-cart" ),
		'UG211' => esc_html__( 'Soroti', "ncs-cart" ),
		'UG212' => esc_html__( 'Tororo', "ncs-cart" ),
		'UG113' => esc_html__( 'Wakiso', "ncs-cart" ),
		'UG313' => esc_html__( 'Yumbe', "ncs-cart" ),
		'UG330' => esc_html__( 'Zombo', "ncs-cart" ),
	),
	'UM' => array(
		'81' => esc_html__( 'Baker Island', "ncs-cart" ),
		'84' => esc_html__( 'Howland Island', "ncs-cart" ),
		'86' => esc_html__( 'Jarvis Island', "ncs-cart" ),
		'67' => esc_html__( 'Johnston Atoll', "ncs-cart" ),
		'89' => esc_html__( 'Kingman Reef', "ncs-cart" ),
		'71' => esc_html__( 'Midway Atoll', "ncs-cart" ),
		'76' => esc_html__( 'Navassa Island', "ncs-cart" ),
		'95' => esc_html__( 'Palmyra Atoll', "ncs-cart" ),
		'79' => esc_html__( 'Wake Island', "ncs-cart" ),
	),
	'US' => array( // United States.
		'AL' => esc_html__( 'Alabama', "ncs-cart" ),
		'AK' => esc_html__( 'Alaska', "ncs-cart" ),
		'AZ' => esc_html__( 'Arizona', "ncs-cart" ),
		'AR' => esc_html__( 'Arkansas', "ncs-cart" ),
		'CA' => esc_html__( 'California', "ncs-cart" ),
		'CO' => esc_html__( 'Colorado', "ncs-cart" ),
		'CT' => esc_html__( 'Connecticut', "ncs-cart" ),
		'DE' => esc_html__( 'Delaware', "ncs-cart" ),
		'DC' => esc_html__( 'District Of Columbia', "ncs-cart" ),
		'FL' => esc_html__( 'Florida', "ncs-cart" ),
		'GA' => _x( 'Georgia', 'US state of Georgia', "ncs-cart" ),
		'HI' => esc_html__( 'Hawaii', "ncs-cart" ),
		'ID' => esc_html__( 'Idaho', "ncs-cart" ),
		'IL' => esc_html__( 'Illinois', "ncs-cart" ),
		'IN' => esc_html__( 'Indiana', "ncs-cart" ),
		'IA' => esc_html__( 'Iowa', "ncs-cart" ),
		'KS' => esc_html__( 'Kansas', "ncs-cart" ),
		'KY' => esc_html__( 'Kentucky', "ncs-cart" ),
		'LA' => esc_html__( 'Louisiana', "ncs-cart" ),
		'ME' => esc_html__( 'Maine', "ncs-cart" ),
		'MD' => esc_html__( 'Maryland', "ncs-cart" ),
		'MA' => esc_html__( 'Massachusetts', "ncs-cart" ),
		'MI' => esc_html__( 'Michigan', "ncs-cart" ),
		'MN' => esc_html__( 'Minnesota', "ncs-cart" ),
		'MS' => esc_html__( 'Mississippi', "ncs-cart" ),
		'MO' => esc_html__( 'Missouri', "ncs-cart" ),
		'MT' => esc_html__( 'Montana', "ncs-cart" ),
		'NE' => esc_html__( 'Nebraska', "ncs-cart" ),
		'NV' => esc_html__( 'Nevada', "ncs-cart" ),
		'NH' => esc_html__( 'New Hampshire', "ncs-cart" ),
		'NJ' => esc_html__( 'New Jersey', "ncs-cart" ),
		'NM' => esc_html__( 'New Mexico', "ncs-cart" ),
		'NY' => esc_html__( 'New York', "ncs-cart" ),
		'NC' => esc_html__( 'North Carolina', "ncs-cart" ),
		'ND' => esc_html__( 'North Dakota', "ncs-cart" ),
		'OH' => esc_html__( 'Ohio', "ncs-cart" ),
		'OK' => esc_html__( 'Oklahoma', "ncs-cart" ),
		'OR' => esc_html__( 'Oregon', "ncs-cart" ),
		'PA' => esc_html__( 'Pennsylvania', "ncs-cart" ),
		'RI' => esc_html__( 'Rhode Island', "ncs-cart" ),
		'SC' => esc_html__( 'South Carolina', "ncs-cart" ),
		'SD' => esc_html__( 'South Dakota', "ncs-cart" ),
		'TN' => esc_html__( 'Tennessee', "ncs-cart" ),
		'TX' => esc_html__( 'Texas', "ncs-cart" ),
		'UT' => esc_html__( 'Utah', "ncs-cart" ),
		'VT' => esc_html__( 'Vermont', "ncs-cart" ),
		'VA' => esc_html__( 'Virginia', "ncs-cart" ),
		'WA' => esc_html__( 'Washington', "ncs-cart" ),
		'WV' => esc_html__( 'West Virginia', "ncs-cart" ),
		'WI' => esc_html__( 'Wisconsin', "ncs-cart" ),
		'WY' => esc_html__( 'Wyoming', "ncs-cart" ),
		'AA' => esc_html__( 'Armed Forces (AA)', "ncs-cart" ),
		'AE' => esc_html__( 'Armed Forces (AE)', "ncs-cart" ),
		'AP' => esc_html__( 'Armed Forces (AP)', "ncs-cart" ),
	),
	'VN' => array(),
	'YT' => array(),
	'ZA' => array( // South African states.
		'EC'  => esc_html__( 'Eastern Cape', "ncs-cart" ),
		'FS'  => esc_html__( 'Free State', "ncs-cart" ),
		'GP'  => esc_html__( 'Gauteng', "ncs-cart" ),
		'KZN' => esc_html__( 'KwaZulu-Natal', "ncs-cart" ),
		'LP'  => esc_html__( 'Limpopo', "ncs-cart" ),
		'MP'  => esc_html__( 'Mpumalanga', "ncs-cart" ),
		'NC'  => esc_html__( 'Northern Cape', "ncs-cart" ),
		'NW'  => esc_html__( 'North West', "ncs-cart" ),
		'WC'  => esc_html__( 'Western Cape', "ncs-cart" ),
	),
	'ZM' => array( // Zambia's Provinces. Ref: https://en.wikipedia.org/wiki/ISO_3166-2:ZM.
		'ZM-01' => esc_html__( 'Western', "ncs-cart" ),
		'ZM-02' => esc_html__( 'Central', "ncs-cart" ),
		'ZM-03' => esc_html__( 'Eastern', "ncs-cart" ),
		'ZM-04' => esc_html__( 'Luapula', "ncs-cart" ),
		'ZM-05' => esc_html__( 'Northern', "ncs-cart" ),
		'ZM-06' => esc_html__( 'North-Western', "ncs-cart" ),
		'ZM-07' => esc_html__( 'Southern', "ncs-cart" ),
		'ZM-08' => esc_html__( 'Copperbelt', "ncs-cart" ),
		'ZM-09' => esc_html__( 'Lusaka', "ncs-cart" ),
		'ZM-10' => esc_html__( 'Muchinga', "ncs-cart" ),
	),
);
